Class: Google::Apis::AccesscontextmanagerV1::GcpUserAccessBindingOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::GcpUserAccessBindingOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Currently, a completed operation means nothing. In the future, this metadata and a completed operation may indicate that the binding has taken effect and is affecting access decisions for all users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpUserAccessBindingOperationMetadata
constructor
A new instance of GcpUserAccessBindingOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpUserAccessBindingOperationMetadata
Returns a new instance of GcpUserAccessBindingOperationMetadata.
822 823 824 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 822 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
827 828 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 827 def update!(**args) end |