Class: Google::Apis::AccesscontextmanagerV1::GetPolicyOptions
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::GetPolicyOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Encapsulates settings provided to GetIamPolicy.
Instance Attribute Summary collapse
-
#requested_policy_version ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetPolicyOptions
constructor
A new instance of GetPolicyOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetPolicyOptions
Returns a new instance of GetPolicyOptions.
1204 1205 1206 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1204 def initialize(**args) update!(**args) end |
Instance Attribute Details
#requested_policy_version ⇒ Fixnum
Optional. The maximum policy version that will be used to format the policy.
Valid values are 0, 1, and 3. Requests specifying an invalid value will be
rejected. Requests for policies with any conditional role bindings must
specify version 3. Policies with no conditional role bindings may specify any
valid value or leave the field unset. The policy in the response might use the
policy version that you specified, or it might use a lower policy version. For
example, if you specify version 3, but the policy has no conditional role
bindings, the response uses version 1. To learn which resources support
conditions in their IAM policies, see the IAM documentation.
Corresponds to the JSON property requestedPolicyVersion
1202 1203 1204 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1202 def requested_policy_version @requested_policy_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1209 1210 1211 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1209 def update!(**args) @requested_policy_version = args[:requested_policy_version] if args.key?(:requested_policy_version) end |