Class: Google::Apis::AccesscontextmanagerV1::IngressPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Policy for ingress into ServicePerimeter. IngressPolicies match requests based on ingress_from and ingress_to stanzas. For an ingress policy to match, both the ingress_from and ingress_to stanzas must be matched. If an IngressPolicy matches a request, the request is allowed through the perimeter boundary from outside the perimeter. For example, access from the internet can be allowed either based on an AccessLevel or, for traffic hosted on Google Cloud, the project of the source network. For access from private networks, using the project of the hosting network is required. Individual ingress policies can be limited by restricting which services and/or actions they match using the ingress_to field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngressPolicy

Returns a new instance of IngressPolicy.



1291
1292
1293
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ingress_fromGoogle::Apis::AccesscontextmanagerV1::IngressFrom

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the source of the request. The request must satisfy what is defined in sources AND identity related fields in order to match. Corresponds to the JSON property ingressFrom



1273
1274
1275
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1273

def ingress_from
  @ingress_from
end

#ingress_toGoogle::Apis::AccesscontextmanagerV1::IngressTo

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the ApiOperation intended to be performed on the target resource of the request. The request must satisfy what is defined in operations AND resources in order to match. Corresponds to the JSON property ingressTo



1281
1282
1283
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1281

def ingress_to
  @ingress_to
end

#titleString

Optional. Human-readable title for the ingress rule. The title must be unique within the perimeter and can not exceed 100 characters. Within the access policy, the combined length of all rule titles must not exceed 240,000 characters. Corresponds to the JSON property title

Returns:

  • (String)


1289
1290
1291
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1289

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1296
1297
1298
1299
1300
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1296

def update!(**args)
  @ingress_from = args[:ingress_from] if args.key?(:ingress_from)
  @ingress_to = args[:ingress_to] if args.key?(:ingress_to)
  @title = args[:title] if args.key?(:title)
end