Class: Google::Apis::AccesscontextmanagerV1::MethodSelector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

An allowed method or permission of a service specified in ApiOperation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodSelector

Returns a new instance of MethodSelector.



1610
1611
1612
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#method_propString

A valid method name for the corresponding service_name in ApiOperation. If * is used as the value for the method, then ALL methods and permissions are allowed. Corresponds to the JSON property method

Returns:

  • (String)


1602
1603
1604
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1602

def method_prop
  @method_prop
end

#permissionString

A valid Cloud IAM permission for the corresponding service_name in ApiOperation. Corresponds to the JSON property permission

Returns:

  • (String)


1608
1609
1610
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1608

def permission
  @permission
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1615
1616
1617
1618
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1615

def update!(**args)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @permission = args[:permission] if args.key?(:permission)
end