Class: Google::Apis::AccesscontextmanagerV1::PrivateServiceConnectEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Specifies the Private Service Connect endpoint that an API call refers to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateServiceConnectEndpoint

Returns a new instance of PrivateServiceConnectEndpoint.



1886
1887
1888
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1886

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forwarding_ruleString

The full resource name of the global forwarding rule that identifies a Private Service Connect endpoint. Forwarding rule format: //compute.googleapis.com/ projects/PROJECT_ID/global/forwardingRules/FORWARDING_RULE_ID`. Corresponds to the JSON propertyforwardingRule`

Returns:

  • (String)


1884
1885
1886
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1884

def forwarding_rule
  @forwarding_rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1891
1892
1893
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1891

def update!(**args)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
end