Class: Google::Apis::AccesscontextmanagerV1::ScopedAccessSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

A relationship between access settings and its scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScopedAccessSettings

Returns a new instance of ScopedAccessSettings.



2067
2068
2069
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_settingsGoogle::Apis::AccesscontextmanagerV1::AccessSettings

Access settings represent the set of conditions that must be met for access to be granted. At least one of the fields must be set. Corresponds to the JSON property activeSettings



2053
2054
2055
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2053

def active_settings
  @active_settings
end

#dry_run_settingsGoogle::Apis::AccesscontextmanagerV1::AccessSettings

Access settings represent the set of conditions that must be met for access to be granted. At least one of the fields must be set. Corresponds to the JSON property dryRunSettings



2059
2060
2061
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2059

def dry_run_settings
  @dry_run_settings
end

#scopeGoogle::Apis::AccesscontextmanagerV1::AccessScope

Access scope represents the client scope, etc. to which the settings will be applied to. Corresponds to the JSON property scope



2065
2066
2067
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2065

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2072
2073
2074
2075
2076
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2072

def update!(**args)
  @active_settings = args[:active_settings] if args.key?(:active_settings)
  @dry_run_settings = args[:dry_run_settings] if args.key?(:dry_run_settings)
  @scope = args[:scope] if args.key?(:scope)
end