Class: Google::Apis::AccesscontextmanagerV1::SessionSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Stores settings related to Google Cloud Session Length including session duration, the type of challenge (i.e. method) they should face when their session expires, and other related settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionSettings

Returns a new instance of SessionSettings.



2305
2306
2307
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_inactivityString

Optional. How long a user is allowed to take between actions before a new access token must be issued. Only set for Google Cloud apps. Corresponds to the JSON property maxInactivity

Returns:

  • (String)


2270
2271
2272
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2270

def max_inactivity
  @max_inactivity
end

#session_lengthString

Optional. The session length. Setting this field to zero allows for sessions that are active indefinitely. Also, setting session_length_enabled to false disregards session limits, which means that sessions never expire. If use_oidc_max_age is true, for OIDC apps, the session length will be the minimum of this field and the OIDC max_age param. If this field is set to zero, session_length_enabled must be set to false or left unset. Corresponds to the JSON property sessionLength

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2280

def session_length
  @session_length
end

#session_length_enabledBoolean Also known as: session_length_enabled?

Optional. This field enables or disables Google Cloud session length. When false, all fields set above will be disregarded and the session length is basically infinite. If session_length is set to zero, this field must be set to false. Corresponds to the JSON property sessionLengthEnabled

Returns:

  • (Boolean)


2288
2289
2290
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2288

def session_length_enabled
  @session_length_enabled
end

#session_reauth_methodString

Optional. Session method when user's Google Cloud session is up. Corresponds to the JSON property sessionReauthMethod

Returns:

  • (String)


2294
2295
2296
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2294

def session_reauth_method
  @session_reauth_method
end

#use_oidc_max_ageBoolean Also known as: use_oidc_max_age?

Optional. Only useful for OIDC apps. When false, the OIDC max_age param, if passed in the authentication request will be ignored. When true, the re-auth period will be the minimum of the session_length field and the max_age OIDC param. Corresponds to the JSON property useOidcMaxAge

Returns:

  • (Boolean)


2302
2303
2304
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2302

def use_oidc_max_age
  @use_oidc_max_age
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2310
2311
2312
2313
2314
2315
2316
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2310

def update!(**args)
  @max_inactivity = args[:max_inactivity] if args.key?(:max_inactivity)
  @session_length = args[:session_length] if args.key?(:session_length)
  @session_length_enabled = args[:session_length_enabled] if args.key?(:session_length_enabled)
  @session_reauth_method = args[:session_reauth_method] if args.key?(:session_reauth_method)
  @use_oidc_max_age = args[:use_oidc_max_age] if args.key?(:use_oidc_max_age)
end