Class: Google::Apis::AccesscontextmanagerV1::VpcAccessibleServices

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Specifies how APIs are allowed to communicate within the Service Perimeter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpcAccessibleServices

Returns a new instance of VpcAccessibleServices.



2505
2506
2507
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_service_patternsArray<Google::Apis::AccesscontextmanagerV1::ServicePattern>

Specifies which Google services are allowed to be accessed from VPC networks in the service perimeter. Corresponds to the JSON property allowedServicePatterns



2483
2484
2485
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2483

def allowed_service_patterns
  @allowed_service_patterns
end

#allowed_servicesArray<String>

The list of APIs usable within the Service Perimeter. Must be empty unless ' enable_restriction' is True. You can specify a list of individual services, as well as include the 'RESTRICTED-SERVICES' value, which automatically includes all of the services protected by the perimeter. Corresponds to the JSON property allowedServices

Returns:

  • (Array<String>)


2491
2492
2493
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2491

def allowed_services
  @allowed_services
end

#enable_restrictionBoolean Also known as: enable_restriction?

Whether to restrict API calls within the Service Perimeter to the list of APIs specified in 'allowed_services'. Corresponds to the JSON property enableRestriction

Returns:

  • (Boolean)


2497
2498
2499
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2497

def enable_restriction
  @enable_restriction
end

#service_patterns_enforcement_scopesArray<String>

Defines the enforcement scopes of service patterns. Corresponds to the JSON property servicePatternsEnforcementScopes

Returns:

  • (Array<String>)


2503
2504
2505
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2503

def service_patterns_enforcement_scopes
  @service_patterns_enforcement_scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2510
2511
2512
2513
2514
2515
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2510

def update!(**args)
  @allowed_service_patterns = args[:allowed_service_patterns] if args.key?(:allowed_service_patterns)
  @allowed_services = args[:allowed_services] if args.key?(:allowed_services)
  @enable_restriction = args[:enable_restriction] if args.key?(:enable_restriction)
  @service_patterns_enforcement_scopes = args[:service_patterns_enforcement_scopes] if args.key?(:service_patterns_enforcement_scopes)
end