Class: Google::Apis::AccesscontextmanagerV1::AccessContextManagerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AccesscontextmanagerV1::AccessContextManagerService
- Defined in:
- lib/google/apis/accesscontextmanager_v1/service.rb
Overview
Access Context Manager API
An API for setting attribute based access control to requests to Google Cloud services.
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#commit_service_perimeters(parent, commit_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Commits the dry-run specification for all the service perimeters in an access policy.
-
#create_access_policy(access_policy_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an access policy.
-
#create_access_policy_access_level(parent, access_level_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an access level.
-
#create_access_policy_authorized_orgs_desc(parent, authorized_orgs_desc_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an authorized orgs desc.
-
#create_access_policy_service_perimeter(parent, service_perimeter_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a service perimeter.
-
#create_organization_gcp_user_access_binding(parent, gcp_user_access_binding_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a GcpUserAccessBinding.
-
#delete_access_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an access policy based on the resource name.
-
#delete_access_policy_access_level(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an access level based on the resource name.
-
#delete_access_policy_authorized_orgs_desc(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an authorized orgs desc based on the resource name.
-
#delete_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a service perimeter based on the resource name.
-
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Empty
Deletes a long-running operation.
-
#delete_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a GcpUserAccessBinding.
-
#get_access_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AccessPolicy
Returns an access policy based on the name.
-
#get_access_policy_access_level(name, access_level_format: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AccessLevel
Gets an access level based on the resource name.
-
#get_access_policy_authorized_orgs_desc(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
Gets an authorized orgs desc based on the resource name.
-
#get_access_policy_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Policy
Gets the IAM policy for the specified Access Context Manager access policy.
-
#get_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ServicePerimeter
Gets a service perimeter based on the resource name.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Gets the latest state of a long-running operation.
-
#get_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding
Gets the GcpUserAccessBinding with the given name.
-
#initialize ⇒ AccessContextManagerService
constructor
A new instance of AccessContextManagerService.
-
#list_access_policies(page_size: nil, page_token: nil, parent: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAccessPoliciesResponse
Lists all access policies in an organization.
-
#list_access_policy_access_levels(parent, access_level_format: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAccessLevelsResponse
Lists all access levels for an access policy.
-
#list_access_policy_authorized_orgs_descs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAuthorizedOrgsDescsResponse
Lists all authorized orgs descs for an access policy.
-
#list_access_policy_service_perimeters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListServicePerimetersResponse
Lists all service perimeters for an access policy.
-
#list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_gcp_user_access_bindings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListGcpUserAccessBindingsResponse
Lists all GcpUserAccessBindings for a Google Cloud organization.
-
#patch_access_policy(name, access_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an access policy.
-
#patch_access_policy_access_level(name, access_level_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an access level.
-
#patch_access_policy_authorized_orgs_desc(name, authorized_orgs_desc_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an authorized orgs desc.
-
#patch_access_policy_service_perimeter(name, service_perimeter_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a service perimeter.
-
#patch_organization_gcp_user_access_binding(name, gcp_user_access_binding_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a GcpUserAccessBinding.
-
#replace_access_policy_access_level_all(parent, replace_access_levels_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Replaces all existing access levels in an access policy with the access levels provided.
-
#replace_access_policy_service_perimeter_all(parent, replace_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Replace all existing service perimeters in an access policy with the service perimeters provided.
-
#set_access_policy_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Policy
Sets the IAM policy for the specified Access Context Manager access policy.
-
#test_access_level_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource.
-
#test_access_policy_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource.
-
#test_service_perimeter_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource.
Constructor Details
#initialize ⇒ AccessContextManagerService
Returns a new instance of AccessContextManagerService.
46 47 48 49 50 51 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 46 def initialize super('https://accesscontextmanager.googleapis.com/', '', client_name: 'google-apis-accesscontextmanager_v1', client_version: Google::Apis::AccesscontextmanagerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
39 40 41 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 39 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
44 45 46 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 44 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1124 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Empty::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#commit_service_perimeters(parent, commit_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Commits the dry-run specification for all the service perimeters in an access
policy. A commit operation on a service perimeter involves copying its spec
field to the status field of the service perimeter. Only service perimeters
with use_explicit_dry_run_spec field set to true are affected by a commit
operation. The long-running operation from this RPC has a successful status
after the dry-run specifications for all the service perimeters have been
committed. If a commit fails, it causes the long-running operation to return
an error response and the entire commit operation is cancelled. When
successful, the Operation.response field contains
CommitServicePerimetersResponse. The dry_run and the spec fields are
cleared after a successful commit operation.
826 827 828 829 830 831 832 833 834 835 836 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 826 def commit_service_perimeters(parent, commit_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/servicePerimeters:commit', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::CommitServicePerimetersRequest::Representation command.request_object = commit_service_perimeters_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_access_policy(access_policy_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an access policy. This method fails if the organization already has an
access policy. The long-running operation has a successful status after the
access policy propagates to long-lasting storage. Syntactic and basic semantic
errors are returned in metadata as a BadRequest proto.
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 75 def create_access_policy(access_policy_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/accessPolicies', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AccessPolicy::Representation command.request_object = access_policy_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_access_policy_access_level(parent, access_level_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an access level. The long-running operation from this RPC has a successful status after the access level propagates to long-lasting storage. If access levels contain errors, an error response is returned for the first error encountered.
362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 362 def create_access_policy_access_level(parent, access_level_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/accessLevels', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AccessLevel::Representation command.request_object = access_level_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_access_policy_authorized_orgs_desc(parent, authorized_orgs_desc_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an authorized orgs desc. The long-running operation from this RPC has
a successful status after the authorized orgs desc propagates to long-lasting
storage. If a authorized orgs desc contains errors, an error response is
returned for the first error encountered. The name of this AuthorizedOrgsDesc
will be assigned during creation.
634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 634 def (parent, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/authorizedOrgsDescs', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_access_policy_service_perimeter(parent, service_perimeter_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a service perimeter. The long-running operation from this RPC has a successful status after the service perimeter propagates to long-lasting storage. If a service perimeter contains errors, an error response is returned for the first error encountered.
863 864 865 866 867 868 869 870 871 872 873 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 863 def create_access_policy_service_perimeter(parent, service_perimeter_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/servicePerimeters', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::ServicePerimeter::Representation command.request_object = service_perimeter_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_gcp_user_access_binding(parent, gcp_user_access_binding_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a GcpUserAccessBinding. If the client specifies a name, the server ignores it. Fails if a resource already exists with the same group_key. Completion of this long-running operation does not necessarily signify that the new binding is deployed onto all affected users, which may take more time.
1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1264 def create_organization_gcp_user_access_binding(parent, gcp_user_access_binding_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/gcpUserAccessBindings', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding::Representation command.request_object = gcp_user_access_binding_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_access_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an access policy based on the resource name. The long-running operation has a successful status after the access policy is removed from long- lasting storage.
109 110 111 112 113 114 115 116 117 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 109 def delete_access_policy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_access_policy_access_level(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an access level based on the resource name. The long-running operation from this RPC has a successful status after the access level has been removed from long-lasting storage.
397 398 399 400 401 402 403 404 405 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 397 def delete_access_policy_access_level(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_access_policy_authorized_orgs_desc(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an authorized orgs desc based on the resource name. The long-running operation from this RPC has a successful status after the authorized orgs desc is removed from long-lasting storage.
669 670 671 672 673 674 675 676 677 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 669 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a service perimeter based on the resource name. The long-running operation from this RPC has a successful status after the service perimeter is removed from long-lasting storage.
898 899 900 901 902 903 904 905 906 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 898 def delete_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1159 def delete_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Empty::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a GcpUserAccessBinding. Completion of this long-running operation does not necessarily signify that the binding deletion is deployed onto all affected users, which may take more time.
1298 1299 1300 1301 1302 1303 1304 1305 1306 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1298 def delete_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AccessPolicy
Returns an access policy based on the name.
140 141 142 143 144 145 146 147 148 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 140 def get_access_policy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::AccessPolicy::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::AccessPolicy command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy_access_level(name, access_level_format: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AccessLevel
Gets an access level based on the resource name.
434 435 436 437 438 439 440 441 442 443 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 434 def get_access_policy_access_level(name, access_level_format: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::AccessLevel::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::AccessLevel command.params['name'] = name unless name.nil? command.query['accessLevelFormat'] = access_level_format unless access_level_format.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy_authorized_orgs_desc(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
Gets an authorized orgs desc based on the resource name.
700 701 702 703 704 705 706 707 708 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 700 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Policy
Gets the IAM policy for the specified Access Context Manager access policy.
173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 173 def get_access_policy_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Policy::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ServicePerimeter
Gets a service perimeter based on the resource name.
929 930 931 932 933 934 935 936 937 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 929 def get_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ServicePerimeter::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ServicePerimeter command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1190 1191 1192 1193 1194 1195 1196 1197 1198 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1190 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding
Gets the GcpUserAccessBinding with the given name.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1328 def get_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_access_policies(page_size: nil, page_token: nil, parent: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAccessPoliciesResponse
Lists all access policies in an organization.
211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 211 def list_access_policies(page_size: nil, page_token: nil, parent: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/accessPolicies', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListAccessPoliciesResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListAccessPoliciesResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_access_policy_access_levels(parent, access_level_format: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAccessLevelsResponse
Lists all access levels for an access policy.
475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 475 def list_access_policy_access_levels(parent, access_level_format: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/accessLevels', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListAccessLevelsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListAccessLevelsResponse command.params['parent'] = parent unless parent.nil? command.query['accessLevelFormat'] = access_level_format unless access_level_format.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_access_policy_authorized_orgs_descs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAuthorizedOrgsDescsResponse
Lists all authorized orgs descs for an access policy.
736 737 738 739 740 741 742 743 744 745 746 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 736 def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/authorizedOrgsDescs', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListAuthorizedOrgsDescsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListAuthorizedOrgsDescsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_access_policy_service_perimeters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListServicePerimetersResponse
Lists all service perimeters for an access policy.
965 966 967 968 969 970 971 972 973 974 975 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 965 def list_access_policy_service_perimeters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/servicePerimeters', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListServicePerimetersResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListServicePerimetersResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1227 def list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListOperationsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_gcp_user_access_bindings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListGcpUserAccessBindingsResponse
Lists all GcpUserAccessBindings for a Google Cloud organization.
1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1364 def list_organization_gcp_user_access_bindings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/gcpUserAccessBindings', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListGcpUserAccessBindingsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListGcpUserAccessBindingsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_access_policy(name, access_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an access policy. The long-running operation from this RPC has a successful status after the changes to the access policy propagate to long- lasting storage.
249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 249 def patch_access_policy(name, access_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AccessPolicy::Representation command.request_object = access_policy_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_access_policy_access_level(name, access_level_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an access level. The long-running operation from this RPC has a successful status after the changes to the access level propagate to long- lasting storage. If access levels contain errors, an error response is returned for the first error encountered.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 517 def patch_access_policy_access_level(name, access_level_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AccessLevel::Representation command.request_object = access_level_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_access_policy_authorized_orgs_desc(name, authorized_orgs_desc_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an authorized orgs desc. The long-running operation from this RPC has
a successful status after the authorized orgs desc propagates to long-lasting
storage. If a authorized orgs desc contains errors, an error response is
returned for the first error encountered. Only the organization list in
AuthorizedOrgsDesc can be updated. The name, authorization_type, asset_type
and authorization_direction cannot be updated.
780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 780 def (name, = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_access_policy_service_perimeter(name, service_perimeter_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a service perimeter. The long-running operation from this RPC has a successful status after the service perimeter propagates to long-lasting storage. If a service perimeter contains errors, an error response is returned for the first error encountered.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1006 def patch_access_policy_service_perimeter(name, service_perimeter_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::ServicePerimeter::Representation command.request_object = service_perimeter_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_gcp_user_access_binding(name, gcp_user_access_binding_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a GcpUserAccessBinding. Completion of this long-running operation does not necessarily signify that the changed binding is deployed onto all affected users, which may take more time.
1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1407 def patch_organization_gcp_user_access_binding(name, gcp_user_access_binding_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding::Representation command.request_object = gcp_user_access_binding_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#replace_access_policy_access_level_all(parent, replace_access_levels_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Replaces all existing access levels in an access policy with the access levels provided. This is done atomically. The long-running operation from this RPC has a successful status after all replacements propagate to long-lasting storage. If the replacement contains errors, an error response is returned for the first error encountered. Upon error, the replacement is cancelled, and existing access levels are not affected. The Operation.response field contains ReplaceAccessLevelsResponse. Removing access levels contained in existing service perimeters result in an error.
559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 559 def replace_access_policy_access_level_all(parent, replace_access_levels_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/accessLevels:replaceAll', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::ReplaceAccessLevelsRequest::Representation command.request_object = replace_access_levels_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#replace_access_policy_service_perimeter_all(parent, replace_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Replace all existing service perimeters in an access policy with the service perimeters provided. This is done atomically. The long-running operation from this RPC has a successful status after all replacements propagate to long- lasting storage. Replacements containing errors result in an error response for the first error encountered. Upon an error, replacement are cancelled and existing service perimeters are not affected. The Operation.response field contains ReplaceServicePerimetersResponse.
1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1047 def replace_access_policy_service_perimeter_all(parent, replace_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/servicePerimeters:replaceAll', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::ReplaceServicePerimetersRequest::Representation command.request_object = replace_service_perimeters_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_access_policy_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Policy
Sets the IAM policy for the specified Access Context Manager access policy. This method replaces the existing IAM policy on the access policy. The IAM policy controls the set of users who can perform specific operations on the Access Context Manager access policy.
288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 288 def set_access_policy_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Policy::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_access_level_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource. The resource can be an AccessPolicy, AccessLevel, or ServicePerimeter. This method does not support other resources.
596 597 598 599 600 601 602 603 604 605 606 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 596 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_access_policy_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource. The resource can be an AccessPolicy, AccessLevel, or ServicePerimeter. This method does not support other resources.
325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 325 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_service_perimeter_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource. The resource can be an AccessPolicy, AccessLevel, or ServicePerimeter. This method does not support other resources.
1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1084 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |