Class: Google::Apis::AccesscontextmanagerV1::AccessContextManagerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AccesscontextmanagerV1::AccessContextManagerService
- Defined in:
- lib/google/apis/accesscontextmanager_v1/service.rb
Overview
Access Context Manager API
An API for setting attribute based access control to requests to GCP services.
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#commit_service_perimeters(parent, commit_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Commits the dry-run specification for all the service perimeters in an access policy.
-
#create_access_policy(access_policy_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an access policy.
-
#create_access_policy_access_level(parent, access_level_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an access level.
-
#create_access_policy_authorized_orgs_desc(parent, authorized_orgs_desc_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a authorized orgs desc.
-
#create_access_policy_service_perimeter(parent, service_perimeter_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a service perimeter.
-
#create_organization_gcp_user_access_binding(parent, gcp_user_access_binding_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a GcpUserAccessBinding.
-
#delete_access_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an access policy based on the resource name.
-
#delete_access_policy_access_level(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an access level based on the resource name.
-
#delete_access_policy_authorized_orgs_desc(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a authorized orgs desc based on the resource name.
-
#delete_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a service perimeter based on the resource name.
-
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Empty
Deletes a long-running operation.
-
#delete_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a GcpUserAccessBinding.
-
#get_access_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AccessPolicy
Returns an access policy based on the name.
-
#get_access_policy_access_level(name, access_level_format: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AccessLevel
Gets an access level based on the resource name.
-
#get_access_policy_authorized_orgs_desc(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
Gets a authorized orgs desc based on the resource name.
-
#get_access_policy_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Policy
Gets the IAM policy for the specified Access Context Manager access policy.
-
#get_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ServicePerimeter
Gets a service perimeter based on the resource name.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Gets the latest state of a long-running operation.
-
#get_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding
Gets the GcpUserAccessBinding with the given name.
-
#initialize ⇒ AccessContextManagerService
constructor
A new instance of AccessContextManagerService.
-
#list_access_policies(page_size: nil, page_token: nil, parent: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAccessPoliciesResponse
Lists all access policies in an organization.
-
#list_access_policy_access_levels(parent, access_level_format: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAccessLevelsResponse
Lists all access levels for an access policy.
-
#list_access_policy_authorized_orgs_descs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAuthorizedOrgsDescsResponse
Lists all authorized orgs descs for an access policy.
-
#list_access_policy_service_perimeters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListServicePerimetersResponse
Lists all service perimeters for an access policy.
-
#list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_gcp_user_access_bindings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListGcpUserAccessBindingsResponse
Lists all GcpUserAccessBindings for a Google Cloud organization.
-
#patch_access_policy(name, access_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an access policy.
-
#patch_access_policy_access_level(name, access_level_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an access level.
-
#patch_access_policy_authorized_orgs_desc(name, authorized_orgs_desc_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a authorized orgs desc.
-
#patch_access_policy_service_perimeter(name, service_perimeter_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a service perimeter.
-
#patch_organization_gcp_user_access_binding(name, gcp_user_access_binding_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a GcpUserAccessBinding.
-
#replace_access_policy_access_level_all(parent, replace_access_levels_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Replaces all existing access levels in an access policy with the access levels provided.
-
#replace_access_policy_service_perimeter_all(parent, replace_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Replace all existing service perimeters in an access policy with the service perimeters provided.
-
#set_access_policy_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Policy
Sets the IAM policy for the specified Access Context Manager access policy.
-
#test_access_level_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource.
-
#test_access_policy_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource.
-
#test_service_perimeter_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource.
Constructor Details
#initialize ⇒ AccessContextManagerService
Returns a new instance of AccessContextManagerService.
45 46 47 48 49 50 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 45 def initialize super('https://accesscontextmanager.googleapis.com/', '', client_name: 'google-apis-accesscontextmanager_v1', client_version: Google::Apis::AccesscontextmanagerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
38 39 40 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 38 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
43 44 45 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 43 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1123 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Empty::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#commit_service_perimeters(parent, commit_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Commits the dry-run specification for all the service perimeters in an access
policy. A commit operation on a service perimeter involves copying its spec
field to the status field of the service perimeter. Only service perimeters
with use_explicit_dry_run_spec field set to true are affected by a commit
operation. The long-running operation from this RPC has a successful status
after the dry-run specifications for all the service perimeters have been
committed. If a commit fails, it causes the long-running operation to return
an error response and the entire commit operation is cancelled. When
successful, the Operation.response field contains
CommitServicePerimetersResponse. The dry_run and the spec fields are
cleared after a successful commit operation.
825 826 827 828 829 830 831 832 833 834 835 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 825 def commit_service_perimeters(parent, commit_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/servicePerimeters:commit', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::CommitServicePerimetersRequest::Representation command.request_object = commit_service_perimeters_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_access_policy(access_policy_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an access policy. This method fails if the organization already has an
access policy. The long-running operation has a successful status after the
access policy propagates to long-lasting storage. Syntactic and basic semantic
errors are returned in metadata as a BadRequest proto.
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 74 def create_access_policy(access_policy_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/accessPolicies', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AccessPolicy::Representation command.request_object = access_policy_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_access_policy_access_level(parent, access_level_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates an access level. The long-running operation from this RPC has a successful status after the access level propagates to long-lasting storage. If access levels contain errors, an error response is returned for the first error encountered.
361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 361 def create_access_policy_access_level(parent, access_level_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/accessLevels', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AccessLevel::Representation command.request_object = access_level_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_access_policy_authorized_orgs_desc(parent, authorized_orgs_desc_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a authorized orgs desc. The long-running operation from this RPC has a
successful status after the authorized orgs desc propagates to long-lasting
storage. If a authorized orgs desc contains errors, an error response is
returned for the first error encountered. The name of this AuthorizedOrgsDesc
will be assigned during creation.
633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 633 def (parent, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/authorizedOrgsDescs', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_access_policy_service_perimeter(parent, service_perimeter_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a service perimeter. The long-running operation from this RPC has a successful status after the service perimeter propagates to long-lasting storage. If a service perimeter contains errors, an error response is returned for the first error encountered.
862 863 864 865 866 867 868 869 870 871 872 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 862 def create_access_policy_service_perimeter(parent, service_perimeter_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/servicePerimeters', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::ServicePerimeter::Representation command.request_object = service_perimeter_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_gcp_user_access_binding(parent, gcp_user_access_binding_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Creates a GcpUserAccessBinding. If the client specifies a name, the server ignores it. Fails if a resource already exists with the same group_key. Completion of this long-running operation does not necessarily signify that the new binding is deployed onto all affected users, which may take more time.
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1269 def create_organization_gcp_user_access_binding(parent, gcp_user_access_binding_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/gcpUserAccessBindings', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding::Representation command.request_object = gcp_user_access_binding_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_access_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an access policy based on the resource name. The long-running operation has a successful status after the access policy is removed from long- lasting storage.
108 109 110 111 112 113 114 115 116 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 108 def delete_access_policy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_access_policy_access_level(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes an access level based on the resource name. The long-running operation from this RPC has a successful status after the access level has been removed from long-lasting storage.
396 397 398 399 400 401 402 403 404 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 396 def delete_access_policy_access_level(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_access_policy_authorized_orgs_desc(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a authorized orgs desc based on the resource name. The long-running operation from this RPC has a successful status after the authorized orgs desc is removed from long-lasting storage.
668 669 670 671 672 673 674 675 676 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 668 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a service perimeter based on the resource name. The long-running operation from this RPC has a successful status after the service perimeter is removed from long-lasting storage.
897 898 899 900 901 902 903 904 905 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 897 def delete_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1158 1159 1160 1161 1162 1163 1164 1165 1166 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1158 def delete_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Empty::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Deletes a GcpUserAccessBinding. Completion of this long-running operation does not necessarily signify that the binding deletion is deployed onto all affected users, which may take more time.
1303 1304 1305 1306 1307 1308 1309 1310 1311 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1303 def delete_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AccessPolicy
Returns an access policy based on the name.
139 140 141 142 143 144 145 146 147 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 139 def get_access_policy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::AccessPolicy::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::AccessPolicy command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy_access_level(name, access_level_format: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AccessLevel
Gets an access level based on the resource name.
433 434 435 436 437 438 439 440 441 442 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 433 def get_access_policy_access_level(name, access_level_format: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::AccessLevel::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::AccessLevel command.params['name'] = name unless name.nil? command.query['accessLevelFormat'] = access_level_format unless access_level_format.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy_authorized_orgs_desc(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
Gets a authorized orgs desc based on the resource name.
699 700 701 702 703 704 705 706 707 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 699 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Policy
Gets the IAM policy for the specified Access Context Manager access policy.
172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 172 def get_access_policy_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Policy::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ServicePerimeter
Gets a service perimeter based on the resource name.
928 929 930 931 932 933 934 935 936 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 928 def get_access_policy_service_perimeter(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ServicePerimeter::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ServicePerimeter command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1189 1190 1191 1192 1193 1194 1195 1196 1197 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1189 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding
Gets the GcpUserAccessBinding with the given name.
1333 1334 1335 1336 1337 1338 1339 1340 1341 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1333 def get_organization_gcp_user_access_binding(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_access_policies(page_size: nil, page_token: nil, parent: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAccessPoliciesResponse
Lists all access policies in an organization.
210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 210 def list_access_policies(page_size: nil, page_token: nil, parent: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/accessPolicies', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListAccessPoliciesResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListAccessPoliciesResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_access_policy_access_levels(parent, access_level_format: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAccessLevelsResponse
Lists all access levels for an access policy.
474 475 476 477 478 479 480 481 482 483 484 485 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 474 def list_access_policy_access_levels(parent, access_level_format: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/accessLevels', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListAccessLevelsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListAccessLevelsResponse command.params['parent'] = parent unless parent.nil? command.query['accessLevelFormat'] = access_level_format unless access_level_format.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_access_policy_authorized_orgs_descs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListAuthorizedOrgsDescsResponse
Lists all authorized orgs descs for an access policy.
735 736 737 738 739 740 741 742 743 744 745 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 735 def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/authorizedOrgsDescs', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListAuthorizedOrgsDescsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListAuthorizedOrgsDescsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_access_policy_service_perimeters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListServicePerimetersResponse
Lists all service perimeters for an access policy.
964 965 966 967 968 969 970 971 972 973 974 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 964 def list_access_policy_service_perimeters(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/servicePerimeters', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListServicePerimetersResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListServicePerimetersResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED. NOTE: the name
binding allows API services to override the binding to use different resource
name schemes, such as users/*/operations. To override the binding, API
services can add a binding such as "/v1/name=users/*/operations" to their
service configuration. For backwards compatibility, the default name includes
the operations collection id, however overriding users must ensure the name
binding is the parent resource, without the operations collection id.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1232 def list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListOperationsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_gcp_user_access_bindings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::ListGcpUserAccessBindingsResponse
Lists all GcpUserAccessBindings for a Google Cloud organization.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1369 def list_organization_gcp_user_access_bindings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/gcpUserAccessBindings', ) command.response_representation = Google::Apis::AccesscontextmanagerV1::ListGcpUserAccessBindingsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::ListGcpUserAccessBindingsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_access_policy(name, access_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an access policy. The long-running operation from this RPC has a successful status after the changes to the access policy propagate to long- lasting storage.
248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 248 def patch_access_policy(name, access_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AccessPolicy::Representation command.request_object = access_policy_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_access_policy_access_level(name, access_level_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates an access level. The long-running operation from this RPC has a successful status after the changes to the access level propagate to long- lasting storage. If access levels contain errors, an error response is returned for the first error encountered.
516 517 518 519 520 521 522 523 524 525 526 527 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 516 def patch_access_policy_access_level(name, access_level_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AccessLevel::Representation command.request_object = access_level_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_access_policy_authorized_orgs_desc(name, authorized_orgs_desc_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a authorized orgs desc. The long-running operation from this RPC has a
successful status after the authorized orgs desc propagates to long-lasting
storage. If a authorized orgs desc contains errors, an error response is
returned for the first error encountered. Only the organization list in
AuthorizedOrgsDesc can be updated. The name, authorization_type, asset_type
and authorization_direction cannot be updated.
779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 779 def (name, = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_access_policy_service_perimeter(name, service_perimeter_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a service perimeter. The long-running operation from this RPC has a successful status after the service perimeter propagates to long-lasting storage. If a service perimeter contains errors, an error response is returned for the first error encountered.
1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1005 def patch_access_policy_service_perimeter(name, service_perimeter_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::ServicePerimeter::Representation command.request_object = service_perimeter_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_gcp_user_access_binding(name, gcp_user_access_binding_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Updates a GcpUserAccessBinding. Completion of this long-running operation does not necessarily signify that the changed binding is deployed onto all affected users, which may take more time.
1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1412 def patch_organization_gcp_user_access_binding(name, gcp_user_access_binding_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding::Representation command.request_object = gcp_user_access_binding_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#replace_access_policy_access_level_all(parent, replace_access_levels_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Replaces all existing access levels in an access policy with the access levels provided. This is done atomically. The long-running operation from this RPC has a successful status after all replacements propagate to long-lasting storage. If the replacement contains errors, an error response is returned for the first error encountered. Upon error, the replacement is cancelled, and existing access levels are not affected. The Operation.response field contains ReplaceAccessLevelsResponse. Removing access levels contained in existing service perimeters result in an error.
558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 558 def replace_access_policy_access_level_all(parent, replace_access_levels_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/accessLevels:replaceAll', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::ReplaceAccessLevelsRequest::Representation command.request_object = replace_access_levels_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#replace_access_policy_service_perimeter_all(parent, replace_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Operation
Replace all existing service perimeters in an access policy with the service perimeters provided. This is done atomically. The long-running operation from this RPC has a successful status after all replacements propagate to long- lasting storage. Replacements containing errors result in an error response for the first error encountered. Upon an error, replacement are cancelled and existing service perimeters are not affected. The Operation.response field contains ReplaceServicePerimetersResponse.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1046 def replace_access_policy_service_perimeter_all(parent, replace_service_perimeters_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/servicePerimeters:replaceAll', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::ReplaceServicePerimetersRequest::Representation command.request_object = replace_service_perimeters_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Operation::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_access_policy_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::Policy
Sets the IAM policy for the specified Access Context Manager access policy. This method replaces the existing IAM policy on the access policy. The IAM policy controls the set of users who can perform specific operations on the Access Context Manager access policy.
287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 287 def set_access_policy_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::AccesscontextmanagerV1::Policy::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_access_level_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource. The resource can be an AccessPolicy, AccessLevel, or ServicePerimeter. This method does not support other resources.
595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 595 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_access_policy_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource. The resource can be an AccessPolicy, AccessLevel, or ServicePerimeter. This method does not support other resources.
324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 324 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_service_perimeter_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse
Returns the IAM permissions that the caller has on the specified Access Context Manager resource. The resource can be an AccessPolicy, AccessLevel, or ServicePerimeter. This method does not support other resources.
1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 |
# File 'lib/google/apis/accesscontextmanager_v1/service.rb', line 1083 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::AccesscontextmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |