Class: Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
AuthorizedOrgsDesc contains data for an organization's authorization policy.
Instance Attribute Summary collapse
-
#asset_type ⇒ String
The asset type of this authorized orgs desc.
-
#authorization_direction ⇒ String
The direction of the authorization relationship between this organization and the organizations listed in the
orgsfield. -
#authorization_type ⇒ String
A granular control type for authorization levels.
-
#name ⇒ String
Identifier.
-
#orgs ⇒ Array<String>
The list of organization ids in this AuthorizedOrgsDesc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthorizedOrgsDesc
constructor
A new instance of AuthorizedOrgsDesc.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthorizedOrgsDesc
Returns a new instance of AuthorizedOrgsDesc.
382 383 384 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_type ⇒ String
The asset type of this authorized orgs desc. Valid values are
ASSET_TYPE_DEVICE, and ASSET_TYPE_CREDENTIAL_STRENGTH.
Corresponds to the JSON property assetType
343 344 345 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 343 def asset_type @asset_type end |
#authorization_direction ⇒ String
The direction of the authorization relationship between this organization and
the organizations listed in the orgs field. The valid values for this field
include the following: AUTHORIZATION_DIRECTION_FROM: Allows this
organization to evaluate traffic in the organizations listed in the orgs
field. AUTHORIZATION_DIRECTION_TO: Allows the organizations listed in the
orgs field to evaluate the traffic in this organization. For the
authorization relationship to take effect, all of the organizations must
authorize and specify the appropriate relationship direction. For example, if
organization A authorized organization B and C to evaluate its traffic, by
specifying AUTHORIZATION_DIRECTION_TO as the authorization direction,
organizations B and C must specify AUTHORIZATION_DIRECTION_FROM as the
authorization direction in their AuthorizedOrgsDesc resource.
Corresponds to the JSON property authorizationDirection
359 360 361 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 359 def @authorization_direction end |
#authorization_type ⇒ String
A granular control type for authorization levels. Valid value is
AUTHORIZATION_TYPE_TRUST.
Corresponds to the JSON property authorizationType
365 366 367 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 365 def @authorization_type end |
#name ⇒ String
Identifier. Resource name for the AuthorizedOrgsDesc. Format:
accessPolicies/access_policy/authorizedOrgsDescs/authorized_orgs_desc`.
Theauthorized_orgs_desccomponent must begin with a letter, followed by
alphanumeric characters or_. After you create anAuthorizedOrgsDesc, you
cannot change itsname.
Corresponds to the JSON propertyname`
374 375 376 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 374 def name @name end |
#orgs ⇒ Array<String>
The list of organization ids in this AuthorizedOrgsDesc. Format:
organizations/ Example: organizations/123456
Corresponds to the JSON property orgs
380 381 382 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 380 def orgs @orgs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
387 388 389 390 391 392 393 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 387 def update!(**args) @asset_type = args[:asset_type] if args.key?(:asset_type) @authorization_direction = args[:authorization_direction] if args.key?(:authorization_direction) @authorization_type = args[:authorization_type] if args.key?(:authorization_type) @name = args[:name] if args.key?(:name) @orgs = args[:orgs] if args.key?(:orgs) end |