Class: Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
AuthorizedOrgsDesc contains data for an organization's authorization policy.
Instance Attribute Summary collapse
-
#asset_type ⇒ String
The asset type of this authorized orgs desc.
-
#authorization_direction ⇒ String
The direction of the authorization relationship between this organization and the organizations listed in the
orgsfield. -
#authorization_type ⇒ String
A granular control type for authorization levels.
-
#name ⇒ String
Resource name for the
AuthorizedOrgsDesc. -
#orgs ⇒ Array<String>
The list of organization ids in this AuthorizedOrgsDesc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthorizedOrgsDesc
constructor
A new instance of AuthorizedOrgsDesc.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthorizedOrgsDesc
Returns a new instance of AuthorizedOrgsDesc.
297 298 299 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_type ⇒ String
The asset type of this authorized orgs desc. Valid values are
ASSET_TYPE_DEVICE, and ASSET_TYPE_CREDENTIAL_STRENGTH.
Corresponds to the JSON property assetType
258 259 260 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 258 def asset_type @asset_type end |
#authorization_direction ⇒ String
The direction of the authorization relationship between this organization and
the organizations listed in the orgs field. The valid values for this field
include the following: AUTHORIZATION_DIRECTION_FROM: Allows this
organization to evaluate traffic in the organizations listed in the orgs
field. AUTHORIZATION_DIRECTION_TO: Allows the organizations listed in the
orgs field to evaluate the traffic in this organization. For the
authorization relationship to take effect, all of the organizations must
authorize and specify the appropriate relationship direction. For example, if
organization A authorized organization B and C to evaluate its traffic, by
specifying AUTHORIZATION_DIRECTION_TO as the authorization direction,
organizations B and C must specify AUTHORIZATION_DIRECTION_FROM as the
authorization direction in their AuthorizedOrgsDesc resource.
Corresponds to the JSON property authorizationDirection
274 275 276 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 274 def @authorization_direction end |
#authorization_type ⇒ String
A granular control type for authorization levels. Valid value is
AUTHORIZATION_TYPE_TRUST.
Corresponds to the JSON property authorizationType
280 281 282 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 280 def @authorization_type end |
#name ⇒ String
Resource name for the AuthorizedOrgsDesc. Format: accessPolicies/
access_policy/authorizedOrgsDescs/authorized_orgs_desc`. The
authorized_orgs_desccomponent must begin with a letter, followed by
alphanumeric characters or_. After you create anAuthorizedOrgsDesc, you
cannot change itsname.
Corresponds to the JSON propertyname`
289 290 291 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 289 def name @name end |
#orgs ⇒ Array<String>
The list of organization ids in this AuthorizedOrgsDesc. Format:
organizations/ Example: organizations/123456
Corresponds to the JSON property orgs
295 296 297 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 295 def orgs @orgs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
302 303 304 305 306 307 308 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 302 def update!(**args) @asset_type = args[:asset_type] if args.key?(:asset_type) @authorization_direction = args[:authorization_direction] if args.key?(:authorization_direction) @authorization_type = args[:authorization_type] if args.key?(:authorization_type) @name = args[:name] if args.key?(:name) @orgs = args[:orgs] if args.key?(:orgs) end |