Class: Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

AuthorizedOrgsDesc contains data for an organization's authorization policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthorizedOrgsDesc

Returns a new instance of AuthorizedOrgsDesc.



298
299
300
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_typeString

The asset type of this authorized orgs desc. Valid values are ASSET_TYPE_DEVICE, and ASSET_TYPE_CREDENTIAL_STRENGTH. Corresponds to the JSON property assetType

Returns:

  • (String)


259
260
261
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 259

def asset_type
  @asset_type
end

#authorization_directionString

The direction of the authorization relationship between this organization and the organizations listed in the orgs field. The valid values for this field include the following: AUTHORIZATION_DIRECTION_FROM: Allows this organization to evaluate traffic in the organizations listed in the orgs field. AUTHORIZATION_DIRECTION_TO: Allows the organizations listed in the orgs field to evaluate the traffic in this organization. For the authorization relationship to take effect, all of the organizations must authorize and specify the appropriate relationship direction. For example, if organization A authorized organization B and C to evaluate its traffic, by specifying AUTHORIZATION_DIRECTION_TO as the authorization direction, organizations B and C must specify AUTHORIZATION_DIRECTION_FROM as the authorization direction in their AuthorizedOrgsDesc resource. Corresponds to the JSON property authorizationDirection

Returns:

  • (String)


275
276
277
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 275

def authorization_direction
  @authorization_direction
end

#authorization_typeString

A granular control type for authorization levels. Valid value is AUTHORIZATION_TYPE_TRUST. Corresponds to the JSON property authorizationType

Returns:

  • (String)


281
282
283
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 281

def authorization_type
  @authorization_type
end

#nameString

Resource name for the AuthorizedOrgsDesc. Format: accessPolicies/ access_policy/authorizedOrgsDescs/authorized_orgs_desc`. The authorized_orgs_desccomponent must begin with a letter, followed by alphanumeric characters or_. After you create anAuthorizedOrgsDesc, you cannot change itsname. Corresponds to the JSON propertyname`

Returns:

  • (String)


290
291
292
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 290

def name
  @name
end

#orgsArray<String>

The list of organization ids in this AuthorizedOrgsDesc. Format: organizations/ Example: organizations/123456 Corresponds to the JSON property orgs

Returns:

  • (Array<String>)


296
297
298
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 296

def orgs
  @orgs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



303
304
305
306
307
308
309
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 303

def update!(**args)
  @asset_type = args[:asset_type] if args.key?(:asset_type)
  @authorization_direction = args[:authorization_direction] if args.key?(:authorization_direction)
  @authorization_type = args[:authorization_type] if args.key?(:authorization_type)
  @name = args[:name] if args.key?(:name)
  @orgs = args[:orgs] if args.key?(:orgs)
end