Class: Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::AuthorizedOrgsDesc
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
AuthorizedOrgsDesc is a resource that contains a list of organizations for a
authorization type and asset type and its authorization direction.
Instance Attribute Summary collapse
-
#asset_type ⇒ String
The asset type of this authorized orgs desc.
-
#authorization_direction ⇒ String
Authorization direction of this authorization relationship.
-
#authorization_type ⇒ String
The authorization type of this authorized orgs desc.
-
#name ⇒ String
Assigned by the server during creation.
-
#orgs ⇒ Array<String>
The list of organization ids in this AuthorizedOrgsDesc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthorizedOrgsDesc
constructor
A new instance of AuthorizedOrgsDesc.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthorizedOrgsDesc
Returns a new instance of AuthorizedOrgsDesc.
296 297 298 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_type ⇒ String
The asset type of this authorized orgs desc. e.g. device, credential strength.
Corresponds to the JSON property assetType
259 260 261 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 259 def asset_type @asset_type end |
#authorization_direction ⇒ String
Authorization direction of this authorization relationship. i.e. Whether to
allow specified orgs to evaluate this org's traffic, or allow specified orgs'
traffic to be evaluated by this org. Orgs specified as
AUTHORIZATION_DIRECTION_TO in this AuthorizedOrgsDesc[com.google.identity.
accesscontextmanager.v1.AuthorizedOrgsDesc] must also specify this org as the
AUTHORIZATION_DIRECTION_FROM in their own AuthorizedOrgsDesc in order for
this relationship to take effect. Orgs specified as
AUTHORIZATION_DIRECTION_FROM in this AuthorizedOrgsDesc[com.google.identity.
accesscontextmanager.v1.AuthorizedOrgsDesc] must also specify this org as the
AUTHORIZATION_DIRECTION_TO in their own AuthorizedOrgsDesc in order for this
relationship to take effect.
Corresponds to the JSON property authorizationDirection
274 275 276 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 274 def @authorization_direction end |
#authorization_type ⇒ String
The authorization type of this authorized orgs desc. e.g.authorization,
troubleshooting or logging.
Corresponds to the JSON property authorizationType
280 281 282 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 280 def @authorization_type end |
#name ⇒ String
Assigned by the server during creation. The last segment has an arbitrary
length and has only URI unreserved characters (as defined by RFC 3986 Section
2.3). Should not be
specified by the client during creation. Example: "accessPolicies/122256/
authorizedOrgs/b3-BhcX_Ud5N"
Corresponds to the JSON property name
289 290 291 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 289 def name @name end |
#orgs ⇒ Array<String>
The list of organization ids in this AuthorizedOrgsDesc.
Corresponds to the JSON property orgs
294 295 296 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 294 def orgs @orgs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
301 302 303 304 305 306 307 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 301 def update!(**args) @asset_type = args[:asset_type] if args.key?(:asset_type) @authorization_direction = args[:authorization_direction] if args.key?(:authorization_direction) @authorization_type = args[:authorization_type] if args.key?(:authorization_type) @name = args[:name] if args.key?(:name) @orgs = args[:orgs] if args.key?(:orgs) end |