Class: Google::Apis::AccesscontextmanagerV1::BasicLevel
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::BasicLevel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
BasicLevel is an AccessLevel using a set of recommended features.
Instance Attribute Summary collapse
-
#combining_function ⇒ String
How the
conditionslist should be combined to determine if a request is granted thisAccessLevel. -
#conditions ⇒ Array<Google::Apis::AccesscontextmanagerV1::Condition>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BasicLevel
constructor
A new instance of BasicLevel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BasicLevel
Returns a new instance of BasicLevel.
414 415 416 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#combining_function ⇒ String
How the conditions list should be combined to determine if a request is
granted this AccessLevel. If AND is used, each Condition in conditions
must be satisfied for the AccessLevel to be applied. If OR is used, at least
one Condition in conditions must be satisfied for the AccessLevel to be
applied. Default behavior is AND.
Corresponds to the JSON property combiningFunction
407 408 409 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 407 def combining_function @combining_function end |
#conditions ⇒ Array<Google::Apis::AccesscontextmanagerV1::Condition>
Required. A list of requirements for the AccessLevel to be granted.
Corresponds to the JSON property conditions
412 413 414 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 412 def conditions @conditions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
419 420 421 422 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 419 def update!(**args) @combining_function = args[:combining_function] if args.key?(:combining_function) @conditions = args[:conditions] if args.key?(:conditions) end |