Class: Google::Apis::AccesscontextmanagerV1::BasicLevel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

BasicLevel is an AccessLevel using a set of recommended features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BasicLevel

Returns a new instance of BasicLevel.



328
329
330
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#combining_functionString

How the conditions list should be combined to determine if a request is granted this AccessLevel. If AND is used, each Condition in conditions must be satisfied for the AccessLevel to be applied. If OR is used, at least one Condition in conditions must be satisfied for the AccessLevel to be applied. Default behavior is AND. Corresponds to the JSON property combiningFunction

Returns:

  • (String)


321
322
323
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 321

def combining_function
  @combining_function
end

#conditionsArray<Google::Apis::AccesscontextmanagerV1::Condition>

Required. A list of requirements for the AccessLevel to be granted. Corresponds to the JSON property conditions



326
327
328
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 326

def conditions
  @conditions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



333
334
335
336
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 333

def update!(**args)
  @combining_function = args[:combining_function] if args.key?(:combining_function)
  @conditions = args[:conditions] if args.key?(:conditions)
end