Class: Google::Apis::AccesscontextmanagerV1::CommitServicePerimetersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

A request to commit dry-run specs in all Service Perimeters belonging to an Access Policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitServicePerimetersRequest

Returns a new instance of CommitServicePerimetersRequest.



466
467
468
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The etag for the version of the Access Policy that this commit operation is to be performed on. If, at the time of commit, the etag for the Access Policy stored in Access Context Manager is different from the specified etag, then the commit operation will not be performed and the call will fail. This field is not required. If etag is not provided, the operation will be performed as if a valid etag is provided. Corresponds to the JSON property etag

Returns:

  • (String)


464
465
466
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 464

def etag
  @etag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



471
472
473
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 471

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
end