Class: Google::Apis::AccesscontextmanagerV1::CommitServicePerimetersRequest
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::CommitServicePerimetersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
A request to commit dry-run specs in all Service Perimeters belonging to an Access Policy.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitServicePerimetersRequest
constructor
A new instance of CommitServicePerimetersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitServicePerimetersRequest
Returns a new instance of CommitServicePerimetersRequest.
444 445 446 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. The etag for the version of the Access Policy that this commit
operation is to be performed on. If, at the time of commit, the etag for the
Access Policy stored in Access Context Manager is different from the specified
etag, then the commit operation will not be performed and the call will fail.
This field is not required. If etag is not provided, the operation will be
performed as if a valid etag is provided.
Corresponds to the JSON property etag
442 443 444 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 442 def etag @etag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
449 450 451 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 449 def update!(**args) @etag = args[:etag] if args.key?(:etag) end |