Class: Google::Apis::AccesscontextmanagerV1::DevicePolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

DevicePolicy specifies device specific restrictions necessary to acquire a given access level. A DevicePolicy specifies requirements for requests from devices to be granted access levels, it does not do any enforcement on the device. DevicePolicy acts as an AND over all specified fields, and each repeated field is an OR over its elements. Any unset fields are ignored. For example, if the proto is os_type : DESKTOP_WINDOWS, os_type : DESKTOP_LINUX, encryption_status: ENCRYPTED, then the DevicePolicy will be true for requests originating from encrypted Linux desktops and encrypted Windows desktops.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DevicePolicy

Returns a new instance of DevicePolicy.



766
767
768
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_device_management_levelsArray<String>

Allowed device management levels, an empty list allows all management levels. Corresponds to the JSON property allowedDeviceManagementLevels

Returns:

  • (Array<String>)


735
736
737
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 735

def allowed_device_management_levels
  @allowed_device_management_levels
end

#allowed_encryption_statusesArray<String>

Allowed encryptions statuses, an empty list allows all statuses. Corresponds to the JSON property allowedEncryptionStatuses

Returns:

  • (Array<String>)


740
741
742
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 740

def allowed_encryption_statuses
  @allowed_encryption_statuses
end

#os_constraintsArray<Google::Apis::AccesscontextmanagerV1::OsConstraint>

Allowed OS versions, an empty list allows all types and all versions. Corresponds to the JSON property osConstraints



745
746
747
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 745

def os_constraints
  @os_constraints
end

#require_admin_approvalBoolean Also known as: require_admin_approval?

Whether the device needs to be approved by the customer admin. Corresponds to the JSON property requireAdminApproval

Returns:

  • (Boolean)


750
751
752
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 750

def require_admin_approval
  @require_admin_approval
end

#require_corp_ownedBoolean Also known as: require_corp_owned?

Whether the device needs to be corp owned. Corresponds to the JSON property requireCorpOwned

Returns:

  • (Boolean)


756
757
758
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 756

def require_corp_owned
  @require_corp_owned
end

#require_screenlockBoolean Also known as: require_screenlock?

Whether or not screenlock is required for the DevicePolicy to be true. Defaults to false. Corresponds to the JSON property requireScreenlock

Returns:

  • (Boolean)


763
764
765
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 763

def require_screenlock
  @require_screenlock
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



771
772
773
774
775
776
777
778
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 771

def update!(**args)
  @allowed_device_management_levels = args[:allowed_device_management_levels] if args.key?(:allowed_device_management_levels)
  @allowed_encryption_statuses = args[:allowed_encryption_statuses] if args.key?(:allowed_encryption_statuses)
  @os_constraints = args[:os_constraints] if args.key?(:os_constraints)
  @require_admin_approval = args[:require_admin_approval] if args.key?(:require_admin_approval)
  @require_corp_owned = args[:require_corp_owned] if args.key?(:require_corp_owned)
  @require_screenlock = args[:require_screenlock] if args.key?(:require_screenlock)
end