Class: Google::Apis::AccesscontextmanagerV1::EgressFrom

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Defines the conditions under which an EgressPolicy matches a request. Conditions based on information about the source of the request. Note that if the destination of the request is also protected by a ServicePerimeter, then that ServicePerimeter must have an IngressPolicy which allows access in order for this request to succeed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EgressFrom

Returns a new instance of EgressFrom.



708
709
710
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identitiesArray<String>

A list of identities that are allowed access through this [EgressPolicy]. Should be in the format of email address. The email address should represent individual user or service account only. Corresponds to the JSON property identities

Returns:

  • (Array<String>)


686
687
688
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 686

def identities
  @identities
end

#identity_typeString

Specifies the type of identities that are allowed access to outside the perimeter. If left unspecified, then members of identities field will be allowed access. Corresponds to the JSON property identityType

Returns:

  • (String)


693
694
695
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 693

def identity_type
  @identity_type
end

#source_restrictionString

Whether to enforce traffic restrictions based on sources field. If the sources fields is non-empty, then this field must be set to SOURCE_RESTRICTION_ENABLED. Corresponds to the JSON property sourceRestriction

Returns:

  • (String)


700
701
702
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 700

def source_restriction
  @source_restriction
end

#sourcesArray<Google::Apis::AccesscontextmanagerV1::EgressSource>

Sources that this EgressPolicy authorizes access from. If this field is not empty, then source_restriction must be set to SOURCE_RESTRICTION_ENABLED. Corresponds to the JSON property sources



706
707
708
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 706

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



713
714
715
716
717
718
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 713

def update!(**args)
  @identities = args[:identities] if args.key?(:identities)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @source_restriction = args[:source_restriction] if args.key?(:source_restriction)
  @sources = args[:sources] if args.key?(:sources)
end