Class: Google::Apis::AccesscontextmanagerV1::EgressFrom
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::EgressFrom
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Defines the conditions under which an EgressPolicy matches a request. Conditions based on information about the source of the request. Note that if the destination of the request is also protected by a ServicePerimeter, then that ServicePerimeter must have an IngressPolicy which allows access in order for this request to succeed.
Instance Attribute Summary collapse
-
#identities ⇒ Array<String>
A list of identities that are allowed access through this [EgressPolicy].
-
#identity_type ⇒ String
Specifies the type of identities that are allowed access to outside the perimeter.
-
#source_restriction ⇒ String
Whether to enforce traffic restrictions based on
sourcesfield. -
#sources ⇒ Array<Google::Apis::AccesscontextmanagerV1::EgressSource>
Sources that this EgressPolicy authorizes access from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EgressFrom
constructor
A new instance of EgressFrom.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EgressFrom
Returns a new instance of EgressFrom.
686 687 688 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 686 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identities ⇒ Array<String>
A list of identities that are allowed access through this [EgressPolicy].
Should be in the format of email address. The email address should represent
individual user or service account only.
Corresponds to the JSON property identities
664 665 666 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 664 def identities @identities end |
#identity_type ⇒ String
Specifies the type of identities that are allowed access to outside the
perimeter. If left unspecified, then members of identities field will be
allowed access.
Corresponds to the JSON property identityType
671 672 673 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 671 def identity_type @identity_type end |
#source_restriction ⇒ String
Whether to enforce traffic restrictions based on sources field. If the
sources fields is non-empty, then this field must be set to
SOURCE_RESTRICTION_ENABLED.
Corresponds to the JSON property sourceRestriction
678 679 680 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 678 def source_restriction @source_restriction end |
#sources ⇒ Array<Google::Apis::AccesscontextmanagerV1::EgressSource>
Sources that this EgressPolicy authorizes access from. If this field is not
empty, then source_restriction must be set to SOURCE_RESTRICTION_ENABLED.
Corresponds to the JSON property sources
684 685 686 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 684 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
691 692 693 694 695 696 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 691 def update!(**args) @identities = args[:identities] if args.key?(:identities) @identity_type = args[:identity_type] if args.key?(:identity_type) @source_restriction = args[:source_restriction] if args.key?(:source_restriction) @sources = args[:sources] if args.key?(:sources) end |