Class: Google::Apis::AccesscontextmanagerV1::EgressFrom

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Defines the conditions under which an EgressPolicy matches a request. Conditions based on information about the source of the request. Note that if the destination of the request is also protected by a ServicePerimeter, then that ServicePerimeter must have an IngressPolicy which allows access in order for this request to succeed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EgressFrom

Returns a new instance of EgressFrom.



606
607
608
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identitiesArray<String>

A list of identities that are allowed access through this [EgressPolicy]. Should be in the format of email address. The email address should represent individual user or service account only. Corresponds to the JSON property identities

Returns:

  • (Array<String>)


597
598
599
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 597

def identities
  @identities
end

#identity_typeString

Specifies the type of identities that are allowed access to outside the perimeter. If left unspecified, then members of identities field will be allowed access. Corresponds to the JSON property identityType

Returns:

  • (String)


604
605
606
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 604

def identity_type
  @identity_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



611
612
613
614
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 611

def update!(**args)
  @identities = args[:identities] if args.key?(:identities)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
end