Class: Google::Apis::AccesscontextmanagerV1::EgressSource
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::EgressSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
The source that EgressPolicy authorizes access from inside the ServicePerimeter to somewhere outside the ServicePerimeter boundaries.
Instance Attribute Summary collapse
-
#access_level ⇒ String
An AccessLevel resource name that allows protected resources inside the ServicePerimeters to access outside the ServicePerimeter boundaries.
-
#psc_endpoint ⇒ Google::Apis::AccesscontextmanagerV1::PrivateServiceConnectEndpoint
Specifies the Private Service Connect endpoint that an API call refers to.
-
#resource ⇒ String
A Google Cloud resource from the service perimeter that you want to allow to access data outside the perimeter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EgressSource
constructor
A new instance of EgressSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EgressSource
Returns a new instance of EgressSource.
933 934 935 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 933 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_level ⇒ String
An AccessLevel resource name that allows protected resources inside the
ServicePerimeters to access outside the ServicePerimeter boundaries.
AccessLevels listed must be in the same policy as this ServicePerimeter.
Referencing a nonexistent AccessLevel will cause an error. If an AccessLevel
name is not specified, only resources within the perimeter can be accessed
through Google Cloud calls with request origins within the perimeter. Example:
accessPolicies/MY_POLICY/accessLevels/MY_LEVEL. If a single * is specified
for access_level, then all EgressSources will be allowed.
Corresponds to the JSON property accessLevel
918 919 920 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 918 def access_level @access_level end |
#psc_endpoint ⇒ Google::Apis::AccesscontextmanagerV1::PrivateServiceConnectEndpoint
Specifies the Private Service Connect endpoint that an API call refers to.
Corresponds to the JSON property pscEndpoint
923 924 925 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 923 def psc_endpoint @psc_endpoint end |
#resource ⇒ String
A Google Cloud resource from the service perimeter that you want to allow to
access data outside the perimeter. This field supports only projects. The
project format is projects/project_number`. You can't use*in this field
to allow all Google Cloud resources.
Corresponds to the JSON propertyresource`
931 932 933 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 931 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
938 939 940 941 942 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 938 def update!(**args) @access_level = args[:access_level] if args.key?(:access_level) @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint) @resource = args[:resource] if args.key?(:resource) end |