Class: Google::Apis::AccesscontextmanagerV1::EgressSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

The source that EgressPolicy authorizes access from inside the ServicePerimeter to somewhere outside the ServicePerimeter boundaries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EgressSource

Returns a new instance of EgressSource.



903
904
905
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelString

An AccessLevel resource name that allows protected resources inside the ServicePerimeters to access outside the ServicePerimeter boundaries. AccessLevels listed must be in the same policy as this ServicePerimeter. Referencing a nonexistent AccessLevel will cause an error. If an AccessLevel name is not specified, only resources within the perimeter can be accessed through Google Cloud calls with request origins within the perimeter. Example: accessPolicies/MY_POLICY/accessLevels/MY_LEVEL. If a single * is specified for access_level, then all EgressSources will be allowed. Corresponds to the JSON property accessLevel

Returns:

  • (String)


893
894
895
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 893

def access_level
  @access_level
end

#resourceString

A Google Cloud resource from the service perimeter that you want to allow to access data outside the perimeter. This field supports only projects. The project format is projects/project_number`. You can't use*in this field to allow all Google Cloud resources. Corresponds to the JSON propertyresource`

Returns:

  • (String)


901
902
903
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 901

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



908
909
910
911
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 908

def update!(**args)
  @access_level = args[:access_level] if args.key?(:access_level)
  @resource = args[:resource] if args.key?(:resource)
end