Class: Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Restricts access to Cloud Console and Google Cloud APIs for a set of users using Context-Aware Access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpUserAccessBinding

Returns a new instance of GcpUserAccessBinding.



988
989
990
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelsArray<String>

Optional. Access level that a user must have to be granted access. Only one access level is supported, not multiple. This repeated field must have exactly one element. Example: "accessPolicies/9522/accessLevels/device_trusted" Corresponds to the JSON property accessLevels

Returns:

  • (Array<String>)


952
953
954
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 952

def access_levels
  @access_levels
end

#dry_run_access_levelsArray<String>

Optional. Dry run access level that will be evaluated but will not be enforced. The access denial based on dry run policy will be logged. Only one access level is supported, not multiple. This list must have exactly one element. Example: "accessPolicies/9522/accessLevels/device_trusted" Corresponds to the JSON property dryRunAccessLevels

Returns:

  • (Array<String>)


960
961
962
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 960

def dry_run_access_levels
  @dry_run_access_levels
end

#group_keyString

Required. Immutable. Google Group id whose members are subject to this binding' s restrictions. See "id" in the G Suite Directory API's Groups resource . If a group's email address/alias is changed, this resource will continue to point at the changed group. This field does not accept group email addresses or aliases. Example: "01d520gv4vjcrht" Corresponds to the JSON property groupKey

Returns:

  • (String)


970
971
972
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 970

def group_key
  @group_key
end

#nameString

Immutable. Assigned by the server during creation. The last segment has an arbitrary length and has only URI unreserved characters (as defined by RFC 3986 Section 2.3). Should not be specified by the client during creation. Example: "organizations/256/ gcpUserAccessBindings/b3-BhcX_Ud5N" Corresponds to the JSON property name

Returns:

  • (String)


979
980
981
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 979

def name
  @name
end

#restricted_client_applicationsArray<Google::Apis::AccesscontextmanagerV1::Application>

Optional. A list of applications that are subject to this binding's restrictions. If the list is empty, the binding restrictions will universally apply to all applications. Corresponds to the JSON property restrictedClientApplications



986
987
988
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 986

def restricted_client_applications
  @restricted_client_applications
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



993
994
995
996
997
998
999
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 993

def update!(**args)
  @access_levels = args[:access_levels] if args.key?(:access_levels)
  @dry_run_access_levels = args[:dry_run_access_levels] if args.key?(:dry_run_access_levels)
  @group_key = args[:group_key] if args.key?(:group_key)
  @name = args[:name] if args.key?(:name)
  @restricted_client_applications = args[:restricted_client_applications] if args.key?(:restricted_client_applications)
end