Class: Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Restricts access to Cloud Console and Google Cloud APIs for a set of users using Context-Aware Access.
Instance Attribute Summary collapse
-
#access_levels ⇒ Array<String>
Optional.
-
#dry_run_access_levels ⇒ Array<String>
Optional.
-
#group_key ⇒ String
Required.
-
#name ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpUserAccessBinding
constructor
A new instance of GcpUserAccessBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpUserAccessBinding
Returns a new instance of GcpUserAccessBinding.
951 952 953 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_levels ⇒ Array<String>
Optional. Access level that a user must have to be granted access. Only one
access level is supported, not multiple. This repeated field must have exactly
one element. Example: "accessPolicies/9522/accessLevels/device_trusted"
Corresponds to the JSON property accessLevels
922 923 924 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 922 def access_levels @access_levels end |
#dry_run_access_levels ⇒ Array<String>
Optional. Dry run access level that will be evaluated but will not be enforced.
The access denial based on dry run policy will be logged. Only one access
level is supported, not multiple. This list must have exactly one element.
Example: "accessPolicies/9522/accessLevels/device_trusted"
Corresponds to the JSON property dryRunAccessLevels
930 931 932 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 930 def dry_run_access_levels @dry_run_access_levels end |
#group_key ⇒ String
Required. Immutable. Google Group id whose members are subject to this binding'
s restrictions. See "id" in the G Suite Directory API's Groups resource
. If a group's email address/alias is changed, this resource will continue to
point at the changed group. This field does not accept group email addresses
or aliases. Example: "01d520gv4vjcrht"
Corresponds to the JSON property groupKey
940 941 942 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 940 def group_key @group_key end |
#name ⇒ String
Immutable. Assigned by the server during creation. The last segment has an
arbitrary length and has only URI unreserved characters (as defined by RFC
3986 Section 2.3). Should
not be specified by the client during creation. Example: "organizations/256/
gcpUserAccessBindings/b3-BhcX_Ud5N"
Corresponds to the JSON property name
949 950 951 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 949 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
956 957 958 959 960 961 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 956 def update!(**args) @access_levels = args[:access_levels] if args.key?(:access_levels) @dry_run_access_levels = args[:dry_run_access_levels] if args.key?(:dry_run_access_levels) @group_key = args[:group_key] if args.key?(:group_key) @name = args[:name] if args.key?(:name) end |