Class: Google::Apis::AccesscontextmanagerV1::GcpUserAccessBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Restricts access to Cloud Console and Google Cloud APIs for a set of users using Context-Aware Access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpUserAccessBinding

Returns a new instance of GcpUserAccessBinding.



797
798
799
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelsArray<String>

Required. Access level that a user must have to be granted access. Only one access level is supported, not multiple. This repeated field must have exactly one element. Example: "accessPolicies/9522/accessLevels/device_trusted" Corresponds to the JSON property accessLevels

Returns:

  • (Array<String>)


776
777
778
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 776

def access_levels
  @access_levels
end

#group_keyString

Required. Immutable. Google Group id whose members are subject to this binding' s restrictions. See "id" in the G Suite Directory API's Groups resource . If a group's email address/alias is changed, this resource will continue to point at the changed group. This field does not accept group email addresses or aliases. Example: "01d520gv4vjcrht" Corresponds to the JSON property groupKey

Returns:

  • (String)


786
787
788
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 786

def group_key
  @group_key
end

#nameString

Immutable. Assigned by the server during creation. The last segment has an arbitrary length and has only URI unreserved characters (as defined by RFC 3986 Section 2.3). Should not be specified by the client during creation. Example: "organizations/256/ gcpUserAccessBindings/b3-BhcX_Ud5N" Corresponds to the JSON property name

Returns:

  • (String)


795
796
797
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 795

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



802
803
804
805
806
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 802

def update!(**args)
  @access_levels = args[:access_levels] if args.key?(:access_levels)
  @group_key = args[:group_key] if args.key?(:group_key)
  @name = args[:name] if args.key?(:name)
end