Class: Google::Apis::AccesscontextmanagerV1::GcpUserAccessBindingOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Currently, a completed operation means nothing. In the future, this metadata and a completed operation may indicate that the binding has taken effect and is affecting access decisions for all users.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpUserAccessBindingOperationMetadata

Returns a new instance of GcpUserAccessBindingOperationMetadata.



815
816
817
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 815

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



820
821
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 820

def update!(**args)
end