Class: Google::Apis::AccesscontextmanagerV1::IngressFrom
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::IngressFrom
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Defines the conditions under which an IngressPolicy matches a request.
Conditions are based on information about the source of the request. The
request must satisfy what is defined in sources AND identity related fields
in order to match.
Instance Attribute Summary collapse
-
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
-
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the perimeter.
-
#sources ⇒ Array<Google::Apis::AccesscontextmanagerV1::IngressSource>
Sources that this IngressPolicy authorizes access from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngressFrom
constructor
A new instance of IngressFrom.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngressFrom
Returns a new instance of IngressFrom.
1248 1249 1250 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
Identities can be an individual user, service account, Google group, third-
party identity, or agent identity. For the list of supported identity types,
see https://docs.cloud.google.com/vpc-service-controls/docs/supported-
identities.
Corresponds to the JSON property identities
1234 1235 1236 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1234 def identities @identities end |
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the
perimeter. If left unspecified, then members of identities field will be
allowed access.
Corresponds to the JSON property identityType
1241 1242 1243 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1241 def identity_type @identity_type end |
#sources ⇒ Array<Google::Apis::AccesscontextmanagerV1::IngressSource>
Sources that this IngressPolicy authorizes access from.
Corresponds to the JSON property sources
1246 1247 1248 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1246 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1253 1254 1255 1256 1257 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1253 def update!(**args) @identities = args[:identities] if args.key?(:identities) @identity_type = args[:identity_type] if args.key?(:identity_type) @sources = args[:sources] if args.key?(:sources) end |