Class: Google::Apis::AccesscontextmanagerV1::IngressFrom
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::IngressFrom
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Defines the conditions under which an IngressPolicy matches a request.
Conditions are based on information about the source of the request. The
request must satisfy what is defined in sources AND identity related fields
in order to match.
Instance Attribute Summary collapse
-
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
-
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the perimeter.
-
#sources ⇒ Array<Google::Apis::AccesscontextmanagerV1::IngressSource>
Sources that this IngressPolicy authorizes access from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngressFrom
constructor
A new instance of IngressFrom.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngressFrom
Returns a new instance of IngressFrom.
1205 1206 1207 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
Identities can be an individual user, service account, Google group, or third-
party identity. For third-party identity, only single identities are supported
and other identity types are not supported. The v1 identities that have the
prefix user, group, serviceAccount, and principal in https://cloud.
google.com/iam/docs/principal-identifiers#v1 are supported.
Corresponds to the JSON property identities
1191 1192 1193 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1191 def identities @identities end |
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the
perimeter. If left unspecified, then members of identities field will be
allowed access.
Corresponds to the JSON property identityType
1198 1199 1200 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1198 def identity_type @identity_type end |
#sources ⇒ Array<Google::Apis::AccesscontextmanagerV1::IngressSource>
Sources that this IngressPolicy authorizes access from.
Corresponds to the JSON property sources
1203 1204 1205 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1203 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1210 1211 1212 1213 1214 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1210 def update!(**args) @identities = args[:identities] if args.key?(:identities) @identity_type = args[:identity_type] if args.key?(:identity_type) @sources = args[:sources] if args.key?(:sources) end |