Class: Google::Apis::AccesscontextmanagerV1::IngressFrom

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the source of the request. The request must satisfy what is defined in sources AND identity related fields in order to match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngressFrom

Returns a new instance of IngressFrom.



1051
1052
1053
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identitiesArray<String>

A list of identities that are allowed access through this ingress policy, in the format of user:email_idor `serviceAccount:`email_id. Corresponds to the JSON property identities

Returns:

  • (Array<String>)


1037
1038
1039
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1037

def identities
  @identities
end

#identity_typeString

Specifies the type of identities that are allowed access from outside the perimeter. If left unspecified, then members of identities field will be allowed access. Corresponds to the JSON property identityType

Returns:

  • (String)


1044
1045
1046
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1044

def identity_type
  @identity_type
end

#sourcesArray<Google::Apis::AccesscontextmanagerV1::IngressSource>

Sources that this IngressPolicy authorizes access from. Corresponds to the JSON property sources



1049
1050
1051
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1049

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1056
1057
1058
1059
1060
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1056

def update!(**args)
  @identities = args[:identities] if args.key?(:identities)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @sources = args[:sources] if args.key?(:sources)
end