Class: Google::Apis::AccesscontextmanagerV1::IngressFrom
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::IngressFrom
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Defines the conditions under which an IngressPolicy matches a request.
Conditions are based on information about the source of the request. The
request must satisfy what is defined in sources AND identity related fields
in order to match.
Instance Attribute Summary collapse
-
#identities ⇒ Array<String>
A list of identities that are allowed access through this ingress policy.
-
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the perimeter.
-
#sources ⇒ Array<Google::Apis::AccesscontextmanagerV1::IngressSource>
Sources that this IngressPolicy authorizes access from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngressFrom
constructor
A new instance of IngressFrom.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngressFrom
Returns a new instance of IngressFrom.
1028 1029 1030 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identities ⇒ Array<String>
A list of identities that are allowed access through this ingress policy.
Should be in the format of email address. The email address should represent
individual user or service account only.
Corresponds to the JSON property identities
1014 1015 1016 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1014 def identities @identities end |
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the
perimeter. If left unspecified, then members of identities field will be
allowed access.
Corresponds to the JSON property identityType
1021 1022 1023 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1021 def identity_type @identity_type end |
#sources ⇒ Array<Google::Apis::AccesscontextmanagerV1::IngressSource>
Sources that this IngressPolicy authorizes access from.
Corresponds to the JSON property sources
1026 1027 1028 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1026 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1033 1034 1035 1036 1037 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1033 def update!(**args) @identities = args[:identities] if args.key?(:identities) @identity_type = args[:identity_type] if args.key?(:identity_type) @sources = args[:sources] if args.key?(:sources) end |