Class: Google::Apis::AccesscontextmanagerV1::IngressFrom

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the source of the request. The request must satisfy what is defined in sources AND identity related fields in order to match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngressFrom

Returns a new instance of IngressFrom.



897
898
899
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identitiesArray<String>

A list of identities that are allowed access through this ingress policy. Should be in the format of email address. The email address should represent individual user or service account only. Corresponds to the JSON property identities

Returns:

  • (Array<String>)


883
884
885
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 883

def identities
  @identities
end

#identity_typeString

Specifies the type of identities that are allowed access from outside the perimeter. If left unspecified, then members of identities field will be allowed access. Corresponds to the JSON property identityType

Returns:

  • (String)


890
891
892
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 890

def identity_type
  @identity_type
end

#sourcesArray<Google::Apis::AccesscontextmanagerV1::IngressSource>

Sources that this IngressPolicy authorizes access from. Corresponds to the JSON property sources



895
896
897
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 895

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



902
903
904
905
906
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 902

def update!(**args)
  @identities = args[:identities] if args.key?(:identities)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @sources = args[:sources] if args.key?(:sources)
end