Class: Google::Apis::AccesscontextmanagerV1::IngressSource
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::IngressSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
The source that IngressPolicy authorizes access from.
Instance Attribute Summary collapse
-
#access_level ⇒ String
An AccessLevel resource name that allow resources within the ServicePerimeters to be accessed from the internet.
-
#resource ⇒ String
A Google Cloud resource that is allowed to ingress the perimeter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngressSource
constructor
A new instance of IngressSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngressSource
Returns a new instance of IngressSource.
1107 1108 1109 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_level ⇒ String
An AccessLevel resource name that allow resources within the ServicePerimeters
to be accessed from the internet. AccessLevels listed must be in the same
policy as this ServicePerimeter. Referencing a nonexistent AccessLevel will
cause an error. If no AccessLevel names are listed, resources within the
perimeter can only be accessed via Google Cloud calls with request origins
within the perimeter. Example: accessPolicies/MY_POLICY/accessLevels/MY_LEVEL
. If a single * is specified for access_level, then all IngressSources
will be allowed.
Corresponds to the JSON property accessLevel
1094 1095 1096 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1094 def access_level @access_level end |
#resource ⇒ String
A Google Cloud resource that is allowed to ingress the perimeter. Requests
from these resources will be allowed to access perimeter data. Currently only
projects and VPCs are allowed. Project format: projects/project_numberVPC
network format: `//compute.googleapis.com/projects/`PROJECT_ID`/global/
networks/`NAME. The project may be in any Google Cloud organization, not
just the organization that the perimeter is defined in. * is not allowed,
the case of allowing all Google Cloud resources only is not supported.
Corresponds to the JSON property resource
1105 1106 1107 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1105 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1112 1113 1114 1115 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1112 def update!(**args) @access_level = args[:access_level] if args.key?(:access_level) @resource = args[:resource] if args.key?(:resource) end |