Class: Google::Apis::AccesscontextmanagerV1::IngressSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

The source that IngressPolicy authorizes access from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngressSource

Returns a new instance of IngressSource.



1061
1062
1063
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1061

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelString

An AccessLevel resource name that allow resources within the ServicePerimeters to be accessed from the internet. AccessLevels listed must be in the same policy as this ServicePerimeter. Referencing a nonexistent AccessLevel will cause an error. If no AccessLevel names are listed, resources within the perimeter can only be accessed via Google Cloud calls with request origins within the perimeter. Example: accessPolicies/MY_POLICY/accessLevels/MY_LEVEL . If a single * is specified for access_level, then all IngressSources will be allowed. Corresponds to the JSON property accessLevel

Returns:

  • (String)


1048
1049
1050
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1048

def access_level
  @access_level
end

#resourceString

A Google Cloud resource that is allowed to ingress the perimeter. Requests from these resources will be allowed to access perimeter data. Currently only projects and VPCs are allowed. Project format: projects/project_numberVPC network format: `//compute.googleapis.com/projects/`PROJECT_ID`/global/ networks/`NAME. The project may be in any Google Cloud organization, not just the organization that the perimeter is defined in. * is not allowed, the case of allowing all Google Cloud resources only is not supported. Corresponds to the JSON property resource

Returns:

  • (String)


1059
1060
1061
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1059

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1066
1067
1068
1069
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1066

def update!(**args)
  @access_level = args[:access_level] if args.key?(:access_level)
  @resource = args[:resource] if args.key?(:resource)
end