Class: Google::Apis::AccesscontextmanagerV1::IngressTo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the ApiOperation intended to be performed on the target resource of the request. The request must satisfy what is defined in operations AND resources in order to match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngressTo

Returns a new instance of IngressTo.



1380
1381
1382
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::AccesscontextmanagerV1::ApiOperation>

A list of ApiOperations allowed to be performed by the sources specified in corresponding IngressFrom in this ServicePerimeter. Corresponds to the JSON property operations



1364
1365
1366
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1364

def operations
  @operations
end

#resourcesArray<String>

A list of resources, currently only projects in the form projects/, protected by this ServicePerimeter that are allowed to be accessed by sources defined in the corresponding IngressFrom. If a single * is specified, then access to all resources inside the perimeter are allowed. Corresponds to the JSON property resources

Returns:

  • (Array<String>)


1372
1373
1374
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1372

def resources
  @resources
end

#rolesArray<String>

IAM roles that represent the set of operations that the sources specified in the corresponding IngressFrom are allowed to perform in this ServicePerimeter. Corresponds to the JSON property roles

Returns:

  • (Array<String>)


1378
1379
1380
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1378

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1385
1386
1387
1388
1389
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1385

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @resources = args[:resources] if args.key?(:resources)
  @roles = args[:roles] if args.key?(:roles)
end