Class: Google::Apis::AccesscontextmanagerV1::IngressTo
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::IngressTo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Defines the conditions under which an IngressPolicy matches a request.
Conditions are based on information about the ApiOperation intended to be
performed on the target resource of the request. The request must satisfy what
is defined in operations AND resources in order to match.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::AccesscontextmanagerV1::ApiOperation>
A list of ApiOperations allowed to be performed by the sources specified in corresponding IngressFrom in this ServicePerimeter.
-
#resources ⇒ Array<String>
A list of resources, currently only projects in the form
projects/, protected by this ServicePerimeter that are allowed to be accessed by sources defined in the corresponding IngressFrom.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IngressTo
constructor
A new instance of IngressTo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IngressTo
Returns a new instance of IngressTo.
1318 1319 1320 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1318 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::AccesscontextmanagerV1::ApiOperation>
A list of ApiOperations allowed to be performed by the sources specified in
corresponding IngressFrom in this ServicePerimeter.
Corresponds to the JSON property operations
1308 1309 1310 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1308 def operations @operations end |
#resources ⇒ Array<String>
A list of resources, currently only projects in the form projects/,
protected by this ServicePerimeter that are allowed to be accessed by sources
defined in the corresponding IngressFrom. If a single * is specified, then
access to all resources inside the perimeter are allowed.
Corresponds to the JSON property resources
1316 1317 1318 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1316 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1323 1324 1325 1326 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1323 def update!(**args) @operations = args[:operations] if args.key?(:operations) @resources = args[:resources] if args.key?(:resources) end |