Class: Google::Apis::AccesscontextmanagerV1::IngressTo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the ApiOperation intended to be performed on the target resource of the request. The request must satisfy what is defined in operations AND resources in order to match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngressTo

Returns a new instance of IngressTo.



1014
1015
1016
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::AccesscontextmanagerV1::ApiOperation>

A list of ApiOperations allowed to be performed by the sources specified in corresponding IngressFrom in this ServicePerimeter. Corresponds to the JSON property operations



1004
1005
1006
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1004

def operations
  @operations
end

#resourcesArray<String>

A list of resources, currently only projects in the form projects/, protected by this ServicePerimeter that are allowed to be accessed by sources defined in the corresponding IngressFrom. If a single * is specified, then access to all resources inside the perimeter are allowed. Corresponds to the JSON property resources

Returns:

  • (Array<String>)


1012
1013
1014
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1012

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1019
1020
1021
1022
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1019

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @resources = args[:resources] if args.key?(:resources)
end