Class: Google::Apis::AccesscontextmanagerV1::ListSupportedPermissionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

A response to ListSupportedPermissionsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSupportedPermissionsResponse

Returns a new instance of ListSupportedPermissionsResponse.



1556
1557
1558
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Use this pagination token to retrieve the next page of results. An empty value indicates that no further results are available. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1549
1550
1551
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1549

def next_page_token
  @next_page_token
end

#supported_permissionsArray<String>

List of VPC Service Controls supported permissions. Corresponds to the JSON property supportedPermissions

Returns:

  • (Array<String>)


1554
1555
1556
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1554

def supported_permissions
  @supported_permissions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1561
1562
1563
1564
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1561

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @supported_permissions = args[:supported_permissions] if args.key?(:supported_permissions)
end