Class: Google::Apis::AccesscontextmanagerV1::ListSupportedPermissionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::ListSupportedPermissionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
A response to ListSupportedPermissionsRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Use this pagination token to retrieve the next page of results.
-
#supported_permissions ⇒ Array<String>
List of VPC Service Controls supported permissions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSupportedPermissionsResponse
constructor
A new instance of ListSupportedPermissionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSupportedPermissionsResponse
Returns a new instance of ListSupportedPermissionsResponse.
1519 1520 1521 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Use this pagination token to retrieve the next page of results. An empty value
indicates that no further results are available.
Corresponds to the JSON property nextPageToken
1512 1513 1514 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1512 def next_page_token @next_page_token end |
#supported_permissions ⇒ Array<String>
List of VPC Service Controls supported permissions.
Corresponds to the JSON property supportedPermissions
1517 1518 1519 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1517 def @supported_permissions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1524 1525 1526 1527 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1524 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @supported_permissions = args[:supported_permissions] if args.key?(:supported_permissions) end |