Class: Google::Apis::AccesscontextmanagerV1::ListSupportedServicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::ListSupportedServicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
A response to ListSupportedServicesRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Use this pagination token to retrieve the next page of results.
-
#supported_services ⇒ Array<Google::Apis::AccesscontextmanagerV1::SupportedService>
List of services supported by VPC Service Controls instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSupportedServicesResponse
constructor
A new instance of ListSupportedServicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSupportedServicesResponse
Returns a new instance of ListSupportedServicesResponse.
1596 1597 1598 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Use this pagination token to retrieve the next page of results. An empty value
indicates that no further results are available.
Corresponds to the JSON property nextPageToken
1589 1590 1591 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1589 def next_page_token @next_page_token end |
#supported_services ⇒ Array<Google::Apis::AccesscontextmanagerV1::SupportedService>
List of services supported by VPC Service Controls instances.
Corresponds to the JSON property supportedServices
1594 1595 1596 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1594 def supported_services @supported_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1601 1602 1603 1604 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1601 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @supported_services = args[:supported_services] if args.key?(:supported_services) end |