Class: Google::Apis::AccesscontextmanagerV1::ListSupportedServicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::ListSupportedServicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
A response to ListSupportedServicesRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Use this pagination token to retrieve the next page of results.
-
#supported_services ⇒ Array<Google::Apis::AccesscontextmanagerV1::SupportedService>
List of services supported by VPC Service Controls instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSupportedServicesResponse
constructor
A new instance of ListSupportedServicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSupportedServicesResponse
Returns a new instance of ListSupportedServicesResponse.
1582 1583 1584 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Use this pagination token to retrieve the next page of results. An empty value
indicates that no further results are available.
Corresponds to the JSON property nextPageToken
1575 1576 1577 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1575 def next_page_token @next_page_token end |
#supported_services ⇒ Array<Google::Apis::AccesscontextmanagerV1::SupportedService>
List of services supported by VPC Service Controls instances.
Corresponds to the JSON property supportedServices
1580 1581 1582 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1580 def supported_services @supported_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1587 1588 1589 1590 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1587 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @supported_services = args[:supported_services] if args.key?(:supported_services) end |