Class: Google::Apis::AccesscontextmanagerV1::ListSupportedServicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::ListSupportedServicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
A response to ListSupportedServicesRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Use this pagination token to retrieve the next page of results.
-
#supported_services ⇒ Array<Google::Apis::AccesscontextmanagerV1::SupportedService>
List of services supported by VPC Service Controls instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSupportedServicesResponse
constructor
A new instance of ListSupportedServicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSupportedServicesResponse
Returns a new instance of ListSupportedServicesResponse.
1545 1546 1547 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Use this pagination token to retrieve the next page of results. An empty value
indicates that no further results are available.
Corresponds to the JSON property nextPageToken
1538 1539 1540 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1538 def next_page_token @next_page_token end |
#supported_services ⇒ Array<Google::Apis::AccesscontextmanagerV1::SupportedService>
List of services supported by VPC Service Controls instances.
Corresponds to the JSON property supportedServices
1543 1544 1545 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1543 def supported_services @supported_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1550 1551 1552 1553 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1550 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @supported_services = args[:supported_services] if args.key?(:supported_services) end |