Class: Google::Apis::AccesscontextmanagerV1::MethodSelector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

An allowed method or permission of a service specified in ApiOperation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodSelector

Returns a new instance of MethodSelector.



1540
1541
1542
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#method_propString

A valid method name for the corresponding service_name in ApiOperation. If * is used as the value for the method, then ALL methods and permissions are allowed. Corresponds to the JSON property method

Returns:

  • (String)


1532
1533
1534
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1532

def method_prop
  @method_prop
end

#permissionString

A valid Cloud IAM permission for the corresponding service_name in ApiOperation. Corresponds to the JSON property permission

Returns:

  • (String)


1538
1539
1540
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1538

def permission
  @permission
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1545
1546
1547
1548
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1545

def update!(**args)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @permission = args[:permission] if args.key?(:permission)
end