Class: Google::Apis::AccesscontextmanagerV1::MethodSelector
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::MethodSelector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
An allowed method or permission of a service specified in ApiOperation.
Instance Attribute Summary collapse
-
#method_prop ⇒ String
Value for
methodshould be a valid method name for the correspondingservice_namein ApiOperation. -
#permission ⇒ String
Value for
permissionshould be a valid Cloud IAM permission for the correspondingservice_namein ApiOperation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MethodSelector
constructor
A new instance of MethodSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MethodSelector
Returns a new instance of MethodSelector.
1266 1267 1268 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#method_prop ⇒ String
Value for method should be a valid method name for the corresponding
service_name in ApiOperation. If * used as value for method, then ALL
methods and permissions are allowed.
Corresponds to the JSON property method
1258 1259 1260 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1258 def method_prop @method_prop end |
#permission ⇒ String
Value for permission should be a valid Cloud IAM permission for the
corresponding service_name in ApiOperation.
Corresponds to the JSON property permission
1264 1265 1266 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1264 def @permission end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1271 1272 1273 1274 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1271 def update!(**args) @method_prop = args[:method_prop] if args.key?(:method_prop) @permission = args[:permission] if args.key?(:permission) end |