Class: Google::Apis::AccesscontextmanagerV1::Principal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

The comprehensive identity container supporting identities including groups, service accounts and federated identities. Only one of them can be set to create an access binding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Principal

Returns a new instance of Principal.



1864
1865
1866
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_accountString

Immutable. Service account email used to assign policies to a specific service account. If a service account is subject to multiple policies (e.g., if there is a policy for all service accounts in a project and a policy for the service account), the closest (i.e. the most specific) dry-run policy will be used for the dry-run functionality and the closest policy will be used for the enforcement. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1856
1857
1858
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1856

def 
  @service_account
end

#service_account_project_numberString

Immutable. Cloud project number used to assign policies to all service accounts owned by the project. Corresponds to the JSON property serviceAccountProjectNumber

Returns:

  • (String)


1862
1863
1864
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1862

def 
  @service_account_project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1869
1870
1871
1872
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1869

def update!(**args)
  @service_account = args[:service_account] if args.key?(:service_account)
  @service_account_project_number = args[:service_account_project_number] if args.key?(:service_account_project_number)
end