Class: Google::Apis::AccesscontextmanagerV1::PrivateServiceConnectEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::PrivateServiceConnectEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Specifies the Private Service Connect endpoint that an API call refers to.
Instance Attribute Summary collapse
-
#forwarding_rule ⇒ String
The full resource name of the global forwarding rule that identifies a Private Service Connect endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrivateServiceConnectEndpoint
constructor
A new instance of PrivateServiceConnectEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrivateServiceConnectEndpoint
Returns a new instance of PrivateServiceConnectEndpoint.
1845 1846 1847 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forwarding_rule ⇒ String
The full resource name of the global forwarding rule that identifies a Private
Service Connect endpoint. Forwarding rule format: //compute.googleapis.com/
projects/PROJECT_ID/global/forwardingRules/FORWARDING_RULE_ID`.
Corresponds to the JSON propertyforwardingRule`
1843 1844 1845 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1843 def forwarding_rule @forwarding_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1850 1851 1852 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1850 def update!(**args) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) end |