Class: Google::Apis::AccesscontextmanagerV1::ReauthSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Stores settings related to Google Cloud Session Length including session duration, the type of challenge (i.e. method) they should face when their session expires, and other related settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReauthSettings

Returns a new instance of ReauthSettings.



1753
1754
1755
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_inactivityString

Optional. How long a user is allowed to take between actions before a new access token must be issued. Presently only set for Cloud Apps. Corresponds to the JSON property maxInactivity

Returns:

  • (String)


1722
1723
1724
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1722

def max_inactivity
  @max_inactivity
end

#reauth_methodString

Optional. Reauth method when users GCP session is up. Corresponds to the JSON property reauthMethod

Returns:

  • (String)


1727
1728
1729
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1727

def reauth_method
  @reauth_method
end

#session_lengthString

Optional. The session length. Setting this field to zero is equal to disabling. Reauth. Also can set infinite session by flipping the enabled bit to false below. If use_oidc_max_age is true, for OIDC apps, the session length will be the minimum of this field and OIDC max_age param. Corresponds to the JSON property sessionLength

Returns:

  • (String)


1735
1736
1737
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1735

def session_length
  @session_length
end

#session_length_enabledBoolean Also known as: session_length_enabled?

Optional. Big red button to turn off GCSL. When false, all fields set above will be disregarded and the session length is basically infinite. Corresponds to the JSON property sessionLengthEnabled

Returns:

  • (Boolean)


1741
1742
1743
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1741

def session_length_enabled
  @session_length_enabled
end

#use_oidc_max_ageBoolean Also known as: use_oidc_max_age?

Optional. Only useful for OIDC apps. When false, the OIDC max_age param, if passed in the authentication request will be ignored. When true, the re-auth period will be the minimum of the session_length field and the max_age OIDC param. Corresponds to the JSON property useOidcMaxAge

Returns:

  • (Boolean)


1750
1751
1752
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1750

def use_oidc_max_age
  @use_oidc_max_age
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1758
1759
1760
1761
1762
1763
1764
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1758

def update!(**args)
  @max_inactivity = args[:max_inactivity] if args.key?(:max_inactivity)
  @reauth_method = args[:reauth_method] if args.key?(:reauth_method)
  @session_length = args[:session_length] if args.key?(:session_length)
  @session_length_enabled = args[:session_length_enabled] if args.key?(:session_length_enabled)
  @use_oidc_max_age = args[:use_oidc_max_age] if args.key?(:use_oidc_max_age)
end