Class: Google::Apis::AccesscontextmanagerV1::ReplaceAccessLevelsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

A request to replace all existing Access Levels in an Access Policy with the Access Levels provided. This is done atomically.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplaceAccessLevelsRequest

Returns a new instance of ReplaceAccessLevelsRequest.



1766
1767
1768
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelsArray<Google::Apis::AccesscontextmanagerV1::AccessLevel>

Required. The desired Access Levels that should replace all existing Access Levels in the Access Policy. Corresponds to the JSON property accessLevels



1754
1755
1756
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1754

def access_levels
  @access_levels
end

#etagString

Optional. The etag for the version of the Access Policy that this replace operation is to be performed on. If, at the time of replace, the etag for the Access Policy stored in Access Context Manager is different from the specified etag, then the replace operation will not be performed and the call will fail. This field is not required. If etag is not provided, the operation will be performed as if a valid etag is provided. Corresponds to the JSON property etag

Returns:

  • (String)


1764
1765
1766
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1764

def etag
  @etag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1771
1772
1773
1774
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1771

def update!(**args)
  @access_levels = args[:access_levels] if args.key?(:access_levels)
  @etag = args[:etag] if args.key?(:etag)
end