Class: Google::Apis::AccesscontextmanagerV1::ReplaceServicePerimetersRequest
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::ReplaceServicePerimetersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
A request to replace all existing Service Perimeters in an Access Policy with the Service Perimeters provided. This is done atomically.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#service_perimeters ⇒ Array<Google::Apis::AccesscontextmanagerV1::ServicePerimeter>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplaceServicePerimetersRequest
constructor
A new instance of ReplaceServicePerimetersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplaceServicePerimetersRequest
Returns a new instance of ReplaceServicePerimetersRequest.
1648 1649 1650 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1648 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. The etag for the version of the Access Policy that this replace
operation is to be performed on. If, at the time of replace, the etag for the
Access Policy stored in Access Context Manager is different from the specified
etag, then the replace operation will not be performed and the call will fail.
This field is not required. If etag is not provided, the operation will be
performed as if a valid etag is provided.
Corresponds to the JSON property etag
1640 1641 1642 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1640 def etag @etag end |
#service_perimeters ⇒ Array<Google::Apis::AccesscontextmanagerV1::ServicePerimeter>
Required. The desired Service Perimeters that should replace all existing
Service Perimeters in the Access Policy.
Corresponds to the JSON property servicePerimeters
1646 1647 1648 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1646 def service_perimeters @service_perimeters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1653 1654 1655 1656 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1653 def update!(**args) @etag = args[:etag] if args.key?(:etag) @service_perimeters = args[:service_perimeters] if args.key?(:service_perimeters) end |