Class: Google::Apis::AccesscontextmanagerV1::ScopedAccessSettings
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::ScopedAccessSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
A relationship between access settings and its scope.
Instance Attribute Summary collapse
-
#active_settings ⇒ Google::Apis::AccesscontextmanagerV1::AccessSettings
Access settings represent the set of conditions that must be met for access to be granted.
-
#dry_run_settings ⇒ Google::Apis::AccesscontextmanagerV1::AccessSettings
Access settings represent the set of conditions that must be met for access to be granted.
-
#scope ⇒ Google::Apis::AccesscontextmanagerV1::AccessScope
Access scope represents the client scope, etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScopedAccessSettings
constructor
A new instance of ScopedAccessSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScopedAccessSettings
Returns a new instance of ScopedAccessSettings.
2022 2023 2024 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_settings ⇒ Google::Apis::AccesscontextmanagerV1::AccessSettings
Access settings represent the set of conditions that must be met for access to
be granted. At least one of the fields must be set.
Corresponds to the JSON property activeSettings
2008 2009 2010 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2008 def active_settings @active_settings end |
#dry_run_settings ⇒ Google::Apis::AccesscontextmanagerV1::AccessSettings
Access settings represent the set of conditions that must be met for access to
be granted. At least one of the fields must be set.
Corresponds to the JSON property dryRunSettings
2014 2015 2016 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2014 def dry_run_settings @dry_run_settings end |
#scope ⇒ Google::Apis::AccesscontextmanagerV1::AccessScope
Access scope represents the client scope, etc. to which the settings will be
applied to.
Corresponds to the JSON property scope
2020 2021 2022 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2020 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2027 2028 2029 2030 2031 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2027 def update!(**args) @active_settings = args[:active_settings] if args.key?(:active_settings) @dry_run_settings = args[:dry_run_settings] if args.key?(:dry_run_settings) @scope = args[:scope] if args.key?(:scope) end |