Class: Google::Apis::AccesscontextmanagerV1::ScopedAccessSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

A relationship between access settings and its scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScopedAccessSettings

Returns a new instance of ScopedAccessSettings.



1981
1982
1983
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1981

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_settingsGoogle::Apis::AccesscontextmanagerV1::AccessSettings

Access settings represent the set of conditions that must be met for access to be granted. At least one of the fields must be set. Corresponds to the JSON property activeSettings



1967
1968
1969
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1967

def active_settings
  @active_settings
end

#dry_run_settingsGoogle::Apis::AccesscontextmanagerV1::AccessSettings

Access settings represent the set of conditions that must be met for access to be granted. At least one of the fields must be set. Corresponds to the JSON property dryRunSettings



1973
1974
1975
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1973

def dry_run_settings
  @dry_run_settings
end

#scopeGoogle::Apis::AccesscontextmanagerV1::AccessScope

Access scope represents the client scope, etc. to which the settings will be applied to. Corresponds to the JSON property scope



1979
1980
1981
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1979

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1986
1987
1988
1989
1990
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1986

def update!(**args)
  @active_settings = args[:active_settings] if args.key?(:active_settings)
  @dry_run_settings = args[:dry_run_settings] if args.key?(:dry_run_settings)
  @scope = args[:scope] if args.key?(:scope)
end