Class: Google::Apis::AccesscontextmanagerV1::ScopedAccessSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

A relationship between access settings and its scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScopedAccessSettings

Returns a new instance of ScopedAccessSettings.



1857
1858
1859
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_settingsGoogle::Apis::AccesscontextmanagerV1::AccessSettings

Access settings represent the set of conditions that must be met for access to be granted. At least one of the fields must be set. Corresponds to the JSON property activeSettings



1843
1844
1845
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1843

def active_settings
  @active_settings
end

#dry_run_settingsGoogle::Apis::AccesscontextmanagerV1::AccessSettings

Access settings represent the set of conditions that must be met for access to be granted. At least one of the fields must be set. Corresponds to the JSON property dryRunSettings



1849
1850
1851
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1849

def dry_run_settings
  @dry_run_settings
end

#scopeGoogle::Apis::AccesscontextmanagerV1::AccessScope

Access scope represents the client scope, etc. to which the settings will be applied to. Corresponds to the JSON property scope



1855
1856
1857
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1855

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1862
1863
1864
1865
1866
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1862

def update!(**args)
  @active_settings = args[:active_settings] if args.key?(:active_settings)
  @dry_run_settings = args[:dry_run_settings] if args.key?(:dry_run_settings)
  @scope = args[:scope] if args.key?(:scope)
end