Class: Google::Apis::AccesscontextmanagerV1::ServicePattern

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Service patterns used to allow access.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServicePattern

Returns a new instance of ServicePattern.



2092
2093
2094
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modifiersArray<Google::Apis::AccesscontextmanagerV1::Modifier>

Modifiers to apply to the requests that match the URL pattern. Corresponds to the JSON property modifiers



2078
2079
2080
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2078

def modifiers
  @modifiers
end

#patternString

URL pattern to allow. Only patterns of ".googleapis.com/", "www.googleapis. com//" and ".appspot.com/ forms are supported, where should be an alphanumeric name. Corresponds to the JSON property pattern

Returns:

  • (String)


2085
2086
2087
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2085

def pattern
  @pattern
end

#serviceString

Supported service to allow. Corresponds to the JSON property service

Returns:

  • (String)


2090
2091
2092
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2090

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2097
2098
2099
2100
2101
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2097

def update!(**args)
  @modifiers = args[:modifiers] if args.key?(:modifiers)
  @pattern = args[:pattern] if args.key?(:pattern)
  @service = args[:service] if args.key?(:service)
end