Class: Google::Apis::AccesscontextmanagerV1::ServicePattern
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::ServicePattern
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Service patterns used to allow access.
Instance Attribute Summary collapse
-
#modifiers ⇒ Array<Google::Apis::AccesscontextmanagerV1::Modifier>
Modifiers to apply to the requests that match the URL pattern.
-
#pattern ⇒ String
URL pattern to allow.
-
#service ⇒ String
Supported service to allow.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServicePattern
constructor
A new instance of ServicePattern.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServicePattern
Returns a new instance of ServicePattern.
2055 2056 2057 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#modifiers ⇒ Array<Google::Apis::AccesscontextmanagerV1::Modifier>
Modifiers to apply to the requests that match the URL pattern.
Corresponds to the JSON property modifiers
2041 2042 2043 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2041 def modifiers @modifiers end |
#pattern ⇒ String
URL pattern to allow. Only patterns of ".googleapis.com/", "www.googleapis.
com//" and ".appspot.com/ forms are supported, where should be
alphanumerical name.
Corresponds to the JSON property pattern
2048 2049 2050 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2048 def pattern @pattern end |
#service ⇒ String
Supported service to allow.
Corresponds to the JSON property service
2053 2054 2055 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2053 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2060 2061 2062 2063 2064 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2060 def update!(**args) @modifiers = args[:modifiers] if args.key?(:modifiers) @pattern = args[:pattern] if args.key?(:pattern) @service = args[:service] if args.key?(:service) end |