Class: Google::Apis::AccesscontextmanagerV1::ServicePerimeter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

ServicePerimeter describes a set of Google Cloud resources which can freely import and export data amongst themselves, but not export outside of the ServicePerimeter. If a request with a source within this ServicePerimeter has a target outside of the ServicePerimeter, the request will be blocked. Otherwise the request is allowed. There are two types of Service Perimeter - Regular and Bridge. Regular Service Perimeters cannot overlap, a single Google Cloud project can only belong to a single regular Service Perimeter. Service Perimeter Bridges can contain only Google Cloud projects as members, a single Google Cloud project may belong to multiple Service Perimeter Bridges.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServicePerimeter

Returns a new instance of ServicePerimeter.



1535
1536
1537
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of the ServicePerimeter and its use. Does not affect behavior. Corresponds to the JSON property description

Returns:

  • (String)


1486
1487
1488
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1486

def description
  @description
end

#nameString

Required. Resource name for the ServicePerimeter. The short_name component must begin with a letter and only include alphanumeric and '_'. Format: accessPolicies/access_policy/servicePerimeters/service_perimeter` Corresponds to the JSON propertyname`

Returns:

  • (String)


1493
1494
1495
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1493

def name
  @name
end

#perimeter_typeString

Perimeter type indicator. A single project is allowed to be a member of single regular perimeter, but multiple service perimeter bridges. A project cannot be a included in a perimeter bridge without being included in regular perimeter. For perimeter bridges, the restricted service list as well as access level lists must be empty. Corresponds to the JSON property perimeterType

Returns:

  • (String)


1502
1503
1504
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1502

def perimeter_type
  @perimeter_type
end

#specGoogle::Apis::AccesscontextmanagerV1::ServicePerimeterConfig

ServicePerimeterConfig specifies a set of Google Cloud resources that describe specific Service Perimeter configuration. Corresponds to the JSON property spec



1508
1509
1510
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1508

def spec
  @spec
end

#statusGoogle::Apis::AccesscontextmanagerV1::ServicePerimeterConfig

ServicePerimeterConfig specifies a set of Google Cloud resources that describe specific Service Perimeter configuration. Corresponds to the JSON property status



1514
1515
1516
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1514

def status
  @status
end

#titleString

Human readable title. Must be unique within the Policy. Corresponds to the JSON property title

Returns:

  • (String)


1519
1520
1521
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1519

def title
  @title
end

#use_explicit_dry_run_specBoolean Also known as: use_explicit_dry_run_spec?

Use explicit dry run spec flag. Ordinarily, a dry-run spec implicitly exists for all Service Perimeters, and that spec is identical to the status for those Service Perimeters. When this flag is set, it inhibits the generation of the implicit spec, thereby allowing the user to explicitly provide a configuration ("spec") to use in a dry-run version of the Service Perimeter. This allows the user to test changes to the enforced config ("status") without actually enforcing them. This testing is done through analyzing the differences between currently enforced and suggested restrictions. use_explicit_dry_run_spec must bet set to True if any of the fields in the spec are set to non-default values. Corresponds to the JSON property useExplicitDryRunSpec

Returns:

  • (Boolean)


1532
1533
1534
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1532

def use_explicit_dry_run_spec
  @use_explicit_dry_run_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1540
1541
1542
1543
1544
1545
1546
1547
1548
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1540

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @perimeter_type = args[:perimeter_type] if args.key?(:perimeter_type)
  @spec = args[:spec] if args.key?(:spec)
  @status = args[:status] if args.key?(:status)
  @title = args[:title] if args.key?(:title)
  @use_explicit_dry_run_spec = args[:use_explicit_dry_run_spec] if args.key?(:use_explicit_dry_run_spec)
end