Class: Google::Apis::AccesscontextmanagerV1::ServicePerimeterConfig
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::ServicePerimeterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
ServicePerimeterConfig specifies a set of Google Cloud resources that
describe specific Service Perimeter configuration.
Instance Attribute Summary collapse
-
#access_levels ⇒ Array<String>
A list of
AccessLevelresource names that allow resources within theServicePerimeterto be accessed from the internet. -
#egress_policies ⇒ Array<Google::Apis::AccesscontextmanagerV1::EgressPolicy>
List of EgressPolicies to apply to the perimeter.
-
#ingress_policies ⇒ Array<Google::Apis::AccesscontextmanagerV1::IngressPolicy>
List of IngressPolicies to apply to the perimeter.
-
#resources ⇒ Array<String>
A list of Google Cloud resources that are inside of the service perimeter.
-
#restricted_services ⇒ Array<String>
Google Cloud services that are subject to the Service Perimeter restrictions.
-
#vpc_accessible_services ⇒ Google::Apis::AccesscontextmanagerV1::VpcAccessibleServices
Specifies how APIs are allowed to communicate within the Service Perimeter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServicePerimeterConfig
constructor
A new instance of ServicePerimeterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServicePerimeterConfig
Returns a new instance of ServicePerimeterConfig.
2057 2058 2059 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2057 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_levels ⇒ Array<String>
A list of AccessLevel resource names that allow resources within the
ServicePerimeter to be accessed from the internet. AccessLevels listed must
be in the same policy as this ServicePerimeter. Referencing a nonexistent
AccessLevel is a syntax error. If no AccessLevel names are listed,
resources within the perimeter can only be accessed via Google Cloud calls
with request origins within the perimeter. Example: "accessPolicies/MY_POLICY/
accessLevels/MY_LEVEL". For Service Perimeter Bridge, must be empty.
Corresponds to the JSON property accessLevels
2021 2022 2023 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2021 def access_levels @access_levels end |
#egress_policies ⇒ Array<Google::Apis::AccesscontextmanagerV1::EgressPolicy>
List of EgressPolicies to apply to the perimeter. A perimeter may have
multiple EgressPolicies, each of which is evaluated separately. Access is
granted if any EgressPolicy grants it. Must be empty for a perimeter bridge.
Corresponds to the JSON property egressPolicies
2028 2029 2030 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2028 def egress_policies @egress_policies end |
#ingress_policies ⇒ Array<Google::Apis::AccesscontextmanagerV1::IngressPolicy>
List of IngressPolicies to apply to the perimeter. A perimeter may have
multiple IngressPolicies, each of which is evaluated separately. Access is
granted if any Ingress Policy grants it. Must be empty for a perimeter bridge.
Corresponds to the JSON property ingressPolicies
2035 2036 2037 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2035 def ingress_policies @ingress_policies end |
#resources ⇒ Array<String>
A list of Google Cloud resources that are inside of the service perimeter.
Currently only projects and VPCs are allowed. Project format: projects/
project_numberVPC network format: `//compute.googleapis.com/projects/`
PROJECT_ID`/global/networks/`NAME.
Corresponds to the JSON property resources
2043 2044 2045 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2043 def resources @resources end |
#restricted_services ⇒ Array<String>
Google Cloud services that are subject to the Service Perimeter restrictions.
For example, if storage.googleapis.com is specified, access to the storage
buckets inside the perimeter must meet the perimeter's access restrictions.
Corresponds to the JSON property restrictedServices
2050 2051 2052 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2050 def restricted_services @restricted_services end |
#vpc_accessible_services ⇒ Google::Apis::AccesscontextmanagerV1::VpcAccessibleServices
Specifies how APIs are allowed to communicate within the Service Perimeter.
Corresponds to the JSON property vpcAccessibleServices
2055 2056 2057 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2055 def vpc_accessible_services @vpc_accessible_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2062 2063 2064 2065 2066 2067 2068 2069 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2062 def update!(**args) @access_levels = args[:access_levels] if args.key?(:access_levels) @egress_policies = args[:egress_policies] if args.key?(:egress_policies) @ingress_policies = args[:ingress_policies] if args.key?(:ingress_policies) @resources = args[:resources] if args.key?(:resources) @restricted_services = args[:restricted_services] if args.key?(:restricted_services) @vpc_accessible_services = args[:vpc_accessible_services] if args.key?(:vpc_accessible_services) end |