Class: Google::Apis::AccesscontextmanagerV1::ServicePerimeterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

ServicePerimeterConfig specifies a set of Google Cloud resources that describe specific Service Perimeter configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServicePerimeterConfig

Returns a new instance of ServicePerimeterConfig.



1762
1763
1764
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelsArray<String>

A list of AccessLevel resource names that allow resources within the ServicePerimeter to be accessed from the internet. AccessLevels listed must be in the same policy as this ServicePerimeter. Referencing a nonexistent AccessLevel is a syntax error. If no AccessLevel names are listed, resources within the perimeter can only be accessed via Google Cloud calls with request origins within the perimeter. Example: "accessPolicies/MY_POLICY/ accessLevels/MY_LEVEL". For Service Perimeter Bridge, must be empty. Corresponds to the JSON property accessLevels

Returns:

  • (Array<String>)


1726
1727
1728
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1726

def access_levels
  @access_levels
end

#egress_policiesArray<Google::Apis::AccesscontextmanagerV1::EgressPolicy>

List of EgressPolicies to apply to the perimeter. A perimeter may have multiple EgressPolicies, each of which is evaluated separately. Access is granted if any EgressPolicy grants it. Must be empty for a perimeter bridge. Corresponds to the JSON property egressPolicies



1733
1734
1735
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1733

def egress_policies
  @egress_policies
end

#ingress_policiesArray<Google::Apis::AccesscontextmanagerV1::IngressPolicy>

List of IngressPolicies to apply to the perimeter. A perimeter may have multiple IngressPolicies, each of which is evaluated separately. Access is granted if any Ingress Policy grants it. Must be empty for a perimeter bridge. Corresponds to the JSON property ingressPolicies



1740
1741
1742
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1740

def ingress_policies
  @ingress_policies
end

#resourcesArray<String>

A list of Google Cloud resources that are inside of the service perimeter. Currently only projects and VPCs are allowed. Project format: projects/ project_numberVPC network format: `//compute.googleapis.com/projects/` PROJECT_ID`/global/networks/`NAME. Corresponds to the JSON property resources

Returns:

  • (Array<String>)


1748
1749
1750
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1748

def resources
  @resources
end

#restricted_servicesArray<String>

Google Cloud services that are subject to the Service Perimeter restrictions. For example, if storage.googleapis.com is specified, access to the storage buckets inside the perimeter must meet the perimeter's access restrictions. Corresponds to the JSON property restrictedServices

Returns:

  • (Array<String>)


1755
1756
1757
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1755

def restricted_services
  @restricted_services
end

#vpc_accessible_servicesGoogle::Apis::AccesscontextmanagerV1::VpcAccessibleServices

Specifies how APIs are allowed to communicate within the Service Perimeter. Corresponds to the JSON property vpcAccessibleServices



1760
1761
1762
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1760

def vpc_accessible_services
  @vpc_accessible_services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1767
1768
1769
1770
1771
1772
1773
1774
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1767

def update!(**args)
  @access_levels = args[:access_levels] if args.key?(:access_levels)
  @egress_policies = args[:egress_policies] if args.key?(:egress_policies)
  @ingress_policies = args[:ingress_policies] if args.key?(:ingress_policies)
  @resources = args[:resources] if args.key?(:resources)
  @restricted_services = args[:restricted_services] if args.key?(:restricted_services)
  @vpc_accessible_services = args[:vpc_accessible_services] if args.key?(:vpc_accessible_services)
end