Class: Google::Apis::AccesscontextmanagerV1::ServicePerimeterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

ServicePerimeterConfig specifies a set of Google Cloud resources that describe specific Service Perimeter configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServicePerimeterConfig

Returns a new instance of ServicePerimeterConfig.



1599
1600
1601
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_levelsArray<String>

A list of AccessLevel resource names that allow resources within the ServicePerimeter to be accessed from the internet. AccessLevels listed must be in the same policy as this ServicePerimeter. Referencing a nonexistent AccessLevel is a syntax error. If no AccessLevel names are listed, resources within the perimeter can only be accessed via Google Cloud calls with request origins within the perimeter. Example: "accessPolicies/MY_POLICY/ accessLevels/MY_LEVEL". For Service Perimeter Bridge, must be empty. Corresponds to the JSON property accessLevels

Returns:

  • (Array<String>)


1565
1566
1567
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1565

def access_levels
  @access_levels
end

#egress_policiesArray<Google::Apis::AccesscontextmanagerV1::EgressPolicy>

List of EgressPolicies to apply to the perimeter. A perimeter may have multiple EgressPolicies, each of which is evaluated separately. Access is granted if any EgressPolicy grants it. Must be empty for a perimeter bridge. Corresponds to the JSON property egressPolicies



1572
1573
1574
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1572

def egress_policies
  @egress_policies
end

#ingress_policiesArray<Google::Apis::AccesscontextmanagerV1::IngressPolicy>

List of IngressPolicies to apply to the perimeter. A perimeter may have multiple IngressPolicies, each of which is evaluated separately. Access is granted if any Ingress Policy grants it. Must be empty for a perimeter bridge. Corresponds to the JSON property ingressPolicies



1579
1580
1581
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1579

def ingress_policies
  @ingress_policies
end

#resourcesArray<String>

A list of Google Cloud resources that are inside of the service perimeter. Currently only projects are allowed. Format: projects/project_number` Corresponds to the JSON propertyresources`

Returns:

  • (Array<String>)


1585
1586
1587
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1585

def resources
  @resources
end

#restricted_servicesArray<String>

Google Cloud services that are subject to the Service Perimeter restrictions. For example, if storage.googleapis.com is specified, access to the storage buckets inside the perimeter must meet the perimeter's access restrictions. Corresponds to the JSON property restrictedServices

Returns:

  • (Array<String>)


1592
1593
1594
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1592

def restricted_services
  @restricted_services
end

#vpc_accessible_servicesGoogle::Apis::AccesscontextmanagerV1::VpcAccessibleServices

Specifies how APIs are allowed to communicate within the Service Perimeter. Corresponds to the JSON property vpcAccessibleServices



1597
1598
1599
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1597

def vpc_accessible_services
  @vpc_accessible_services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1604
1605
1606
1607
1608
1609
1610
1611
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1604

def update!(**args)
  @access_levels = args[:access_levels] if args.key?(:access_levels)
  @egress_policies = args[:egress_policies] if args.key?(:egress_policies)
  @ingress_policies = args[:ingress_policies] if args.key?(:ingress_policies)
  @resources = args[:resources] if args.key?(:resources)
  @restricted_services = args[:restricted_services] if args.key?(:restricted_services)
  @vpc_accessible_services = args[:vpc_accessible_services] if args.key?(:vpc_accessible_services)
end