Class: Google::Apis::AccesscontextmanagerV1::SessionSettings
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::SessionSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Stores settings related to Google Cloud Session Length including session duration, the type of challenge (i.e. method) they should face when their session expires, and other related settings.
Instance Attribute Summary collapse
-
#max_inactivity ⇒ String
Optional.
-
#session_length ⇒ String
Optional.
-
#session_length_enabled ⇒ Boolean
(also: #session_length_enabled?)
Optional.
-
#session_reauth_method ⇒ String
Optional.
-
#use_oidc_max_age ⇒ Boolean
(also: #use_oidc_max_age?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SessionSettings
constructor
A new instance of SessionSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SessionSettings
Returns a new instance of SessionSettings.
2114 2115 2116 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_inactivity ⇒ String
Optional. How long a user is allowed to take between actions before a new
access token must be issued. Only set for Google Cloud apps.
Corresponds to the JSON property maxInactivity
2082 2083 2084 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2082 def max_inactivity @max_inactivity end |
#session_length ⇒ String
Optional. The session length. Setting this field to zero is equal to disabling
session. Also can set infinite session by flipping the enabled bit to false
below. If use_oidc_max_age is true, for OIDC apps, the session length will be
the minimum of this field and OIDC max_age param.
Corresponds to the JSON property sessionLength
2090 2091 2092 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2090 def session_length @session_length end |
#session_length_enabled ⇒ Boolean Also known as: session_length_enabled?
Optional. This field enables or disables Google Cloud session length. When
false, all fields set above will be disregarded and the session length is
basically infinite.
Corresponds to the JSON property sessionLengthEnabled
2097 2098 2099 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2097 def session_length_enabled @session_length_enabled end |
#session_reauth_method ⇒ String
Optional. Session method when user's Google Cloud session is up.
Corresponds to the JSON property sessionReauthMethod
2103 2104 2105 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2103 def session_reauth_method @session_reauth_method end |
#use_oidc_max_age ⇒ Boolean Also known as: use_oidc_max_age?
Optional. Only useful for OIDC apps. When false, the OIDC max_age param, if
passed in the authentication request will be ignored. When true, the re-auth
period will be the minimum of the session_length field and the max_age OIDC
param.
Corresponds to the JSON property useOidcMaxAge
2111 2112 2113 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2111 def use_oidc_max_age @use_oidc_max_age end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2119 2120 2121 2122 2123 2124 2125 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2119 def update!(**args) @max_inactivity = args[:max_inactivity] if args.key?(:max_inactivity) @session_length = args[:session_length] if args.key?(:session_length) @session_length_enabled = args[:session_length_enabled] if args.key?(:session_length_enabled) @session_reauth_method = args[:session_reauth_method] if args.key?(:session_reauth_method) @use_oidc_max_age = args[:use_oidc_max_age] if args.key?(:use_oidc_max_age) end |