Class: Google::Apis::AccesscontextmanagerV1::SupportedService
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::SupportedService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
SupportedService specifies the VPC Service Controls and its properties.
Instance Attribute Summary collapse
-
#available_on_restricted_vip ⇒ Boolean
(also: #available_on_restricted_vip?)
True if the service is available on the restricted VIP.
-
#known_limitations ⇒ Boolean
(also: #known_limitations?)
True if the service is supported with some limitations.
-
#name ⇒ String
The service name or address of the supported service, such as `service.
-
#service_support_stage ⇒ String
The support stage of the service.
-
#support_stage ⇒ String
The support stage of the service.
-
#supported_methods ⇒ Array<Google::Apis::AccesscontextmanagerV1::MethodSelector>
The list of the supported methods.
-
#title ⇒ String
The name of the supported product, such as 'Cloud Product API'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SupportedService
constructor
A new instance of SupportedService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SupportedService
Returns a new instance of SupportedService.
2419 2420 2421 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_on_restricted_vip ⇒ Boolean Also known as: available_on_restricted_vip?
True if the service is available on the restricted VIP. Services on the
restricted VIP typically either support VPC Service Controls or are core
infrastructure services required for the functioning of Google Cloud.
Corresponds to the JSON property availableOnRestrictedVip
2381 2382 2383 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2381 def available_on_restricted_vip @available_on_restricted_vip end |
#known_limitations ⇒ Boolean Also known as: known_limitations?
True if the service is supported with some limitations. Check documentation for
details.
Corresponds to the JSON property knownLimitations
2389 2390 2391 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2389 def known_limitations @known_limitations end |
#name ⇒ String
The service name or address of the supported service, such as service.
googleapis.com.
Corresponds to the JSON property name
2396 2397 2398 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2396 def name @name end |
#service_support_stage ⇒ String
The support stage of the service.
Corresponds to the JSON property serviceSupportStage
2401 2402 2403 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2401 def service_support_stage @service_support_stage end |
#support_stage ⇒ String
The support stage of the service.
Corresponds to the JSON property supportStage
2406 2407 2408 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2406 def support_stage @support_stage end |
#supported_methods ⇒ Array<Google::Apis::AccesscontextmanagerV1::MethodSelector>
The list of the supported methods. This field exists only in response to
GetSupportedService
Corresponds to the JSON property supportedMethods
2412 2413 2414 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2412 def supported_methods @supported_methods end |
#title ⇒ String
The name of the supported product, such as 'Cloud Product API'.
Corresponds to the JSON property title
2417 2418 2419 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2417 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2424 2425 2426 2427 2428 2429 2430 2431 2432 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2424 def update!(**args) @available_on_restricted_vip = args[:available_on_restricted_vip] if args.key?(:available_on_restricted_vip) @known_limitations = args[:known_limitations] if args.key?(:known_limitations) @name = args[:name] if args.key?(:name) @service_support_stage = args[:service_support_stage] if args.key?(:service_support_stage) @support_stage = args[:support_stage] if args.key?(:support_stage) @supported_methods = args[:supported_methods] if args.key?(:supported_methods) @title = args[:title] if args.key?(:title) end |