Class: Google::Apis::AccesscontextmanagerV1::SupportedService
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::SupportedService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
SupportedService specifies the VPC Service Controls and its properties.
Instance Attribute Summary collapse
-
#available_on_restricted_vip ⇒ Boolean
(also: #available_on_restricted_vip?)
True if the service is available on the restricted VIP.
-
#known_limitations ⇒ Boolean
(also: #known_limitations?)
True if the service is supported with some limitations.
-
#name ⇒ String
The service name or address of the supported service, such as `service.
-
#service_support_stage ⇒ String
The support stage of the service.
-
#support_stage ⇒ String
The support stage of the service.
-
#supported_methods ⇒ Array<Google::Apis::AccesscontextmanagerV1::MethodSelector>
The list of the supported methods.
-
#title ⇒ String
The name of the supported product, such as 'Cloud Product API'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SupportedService
constructor
A new instance of SupportedService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SupportedService
Returns a new instance of SupportedService.
2377 2378 2379 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_on_restricted_vip ⇒ Boolean Also known as: available_on_restricted_vip?
True if the service is available on the restricted VIP. Services on the
restricted VIP typically either support VPC Service Controls or are core
infrastructure services required for the functioning of Google Cloud.
Corresponds to the JSON property availableOnRestrictedVip
2339 2340 2341 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2339 def available_on_restricted_vip @available_on_restricted_vip end |
#known_limitations ⇒ Boolean Also known as: known_limitations?
True if the service is supported with some limitations. Check documentation for
details.
Corresponds to the JSON property knownLimitations
2347 2348 2349 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2347 def known_limitations @known_limitations end |
#name ⇒ String
The service name or address of the supported service, such as service.
googleapis.com.
Corresponds to the JSON property name
2354 2355 2356 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2354 def name @name end |
#service_support_stage ⇒ String
The support stage of the service.
Corresponds to the JSON property serviceSupportStage
2359 2360 2361 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2359 def service_support_stage @service_support_stage end |
#support_stage ⇒ String
The support stage of the service.
Corresponds to the JSON property supportStage
2364 2365 2366 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2364 def support_stage @support_stage end |
#supported_methods ⇒ Array<Google::Apis::AccesscontextmanagerV1::MethodSelector>
The list of the supported methods. This field exists only in response to
GetSupportedService
Corresponds to the JSON property supportedMethods
2370 2371 2372 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2370 def supported_methods @supported_methods end |
#title ⇒ String
The name of the supported product, such as 'Cloud Product API'.
Corresponds to the JSON property title
2375 2376 2377 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2375 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2382 def update!(**args) @available_on_restricted_vip = args[:available_on_restricted_vip] if args.key?(:available_on_restricted_vip) @known_limitations = args[:known_limitations] if args.key?(:known_limitations) @name = args[:name] if args.key?(:name) @service_support_stage = args[:service_support_stage] if args.key?(:service_support_stage) @support_stage = args[:support_stage] if args.key?(:support_stage) @supported_methods = args[:supported_methods] if args.key?(:supported_methods) @title = args[:title] if args.key?(:title) end |