Class: Google::Apis::AccesscontextmanagerV1::SupportedService
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::SupportedService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
SupportedService specifies the VPC Service Controls and its properties.
Instance Attribute Summary collapse
-
#available_on_restricted_vip ⇒ Boolean
(also: #available_on_restricted_vip?)
True if the service is available on the restricted VIP.
-
#known_limitations ⇒ Boolean
(also: #known_limitations?)
True if the service is supported with some limitations.
-
#name ⇒ String
The service name or address of the supported service, such as `service.
-
#service_support_stage ⇒ String
The support stage of the service.
-
#support_stage ⇒ String
The support stage of the service.
-
#supported_methods ⇒ Array<Google::Apis::AccesscontextmanagerV1::MethodSelector>
The list of the supported methods.
-
#title ⇒ String
The name of the supported product, such as 'Cloud Product API'.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SupportedService
constructor
A new instance of SupportedService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SupportedService
Returns a new instance of SupportedService.
2267 2268 2269 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_on_restricted_vip ⇒ Boolean Also known as: available_on_restricted_vip?
True if the service is available on the restricted VIP. Services on the
restricted VIP typically either support VPC Service Controls or are core
infrastructure services required for the functioning of Google Cloud.
Corresponds to the JSON property availableOnRestrictedVip
2229 2230 2231 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2229 def available_on_restricted_vip @available_on_restricted_vip end |
#known_limitations ⇒ Boolean Also known as: known_limitations?
True if the service is supported with some limitations. Check documentation for
details.
Corresponds to the JSON property knownLimitations
2237 2238 2239 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2237 def known_limitations @known_limitations end |
#name ⇒ String
The service name or address of the supported service, such as service.
googleapis.com.
Corresponds to the JSON property name
2244 2245 2246 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2244 def name @name end |
#service_support_stage ⇒ String
The support stage of the service.
Corresponds to the JSON property serviceSupportStage
2249 2250 2251 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2249 def service_support_stage @service_support_stage end |
#support_stage ⇒ String
The support stage of the service.
Corresponds to the JSON property supportStage
2254 2255 2256 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2254 def support_stage @support_stage end |
#supported_methods ⇒ Array<Google::Apis::AccesscontextmanagerV1::MethodSelector>
The list of the supported methods. This field exists only in response to
GetSupportedService
Corresponds to the JSON property supportedMethods
2260 2261 2262 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2260 def supported_methods @supported_methods end |
#title ⇒ String
The name of the supported product, such as 'Cloud Product API'.
Corresponds to the JSON property title
2265 2266 2267 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2265 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2272 2273 2274 2275 2276 2277 2278 2279 2280 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2272 def update!(**args) @available_on_restricted_vip = args[:available_on_restricted_vip] if args.key?(:available_on_restricted_vip) @known_limitations = args[:known_limitations] if args.key?(:known_limitations) @name = args[:name] if args.key?(:name) @service_support_stage = args[:service_support_stage] if args.key?(:service_support_stage) @support_stage = args[:support_stage] if args.key?(:support_stage) @supported_methods = args[:supported_methods] if args.key?(:supported_methods) @title = args[:title] if args.key?(:title) end |