Class: Google::Apis::AccesscontextmanagerV1::SupportedService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

SupportedService specifies the VPC Service Controls and its properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SupportedService

Returns a new instance of SupportedService.



2254
2255
2256
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2254

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_on_restricted_vipBoolean Also known as: available_on_restricted_vip?

True if the service is available on the restricted VIP. Services on the restricted VIP typically either support VPC Service Controls or are core infrastructure services required for the functioning of Google Cloud. Corresponds to the JSON property availableOnRestrictedVip

Returns:

  • (Boolean)


2216
2217
2218
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2216

def available_on_restricted_vip
  @available_on_restricted_vip
end

#known_limitationsBoolean Also known as: known_limitations?

True if the service is supported with some limitations. Check documentation for details. Corresponds to the JSON property knownLimitations

Returns:

  • (Boolean)


2224
2225
2226
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2224

def known_limitations
  @known_limitations
end

#nameString

The service name or address of the supported service, such as service. googleapis.com. Corresponds to the JSON property name

Returns:

  • (String)


2231
2232
2233
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2231

def name
  @name
end

#service_support_stageString

The support stage of the service. Corresponds to the JSON property serviceSupportStage

Returns:

  • (String)


2236
2237
2238
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2236

def service_support_stage
  @service_support_stage
end

#support_stageString

The support stage of the service. Corresponds to the JSON property supportStage

Returns:

  • (String)


2241
2242
2243
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2241

def support_stage
  @support_stage
end

#supported_methodsArray<Google::Apis::AccesscontextmanagerV1::MethodSelector>

The list of the supported methods. This field exists only in response to GetSupportedService Corresponds to the JSON property supportedMethods



2247
2248
2249
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2247

def supported_methods
  @supported_methods
end

#titleString

The name of the supported product, such as 'Cloud Product API'. Corresponds to the JSON property title

Returns:

  • (String)


2252
2253
2254
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2252

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2259
2260
2261
2262
2263
2264
2265
2266
2267
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2259

def update!(**args)
  @available_on_restricted_vip = args[:available_on_restricted_vip] if args.key?(:available_on_restricted_vip)
  @known_limitations = args[:known_limitations] if args.key?(:known_limitations)
  @name = args[:name] if args.key?(:name)
  @service_support_stage = args[:service_support_stage] if args.key?(:service_support_stage)
  @support_stage = args[:support_stage] if args.key?(:support_stage)
  @supported_methods = args[:supported_methods] if args.key?(:supported_methods)
  @title = args[:title] if args.key?(:title)
end