Class: Google::Apis::AccesscontextmanagerV1::SupportedService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

SupportedService specifies the VPC Service Controls and its properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SupportedService

Returns a new instance of SupportedService.



1959
1960
1961
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_on_restricted_vipBoolean Also known as: available_on_restricted_vip?

True if the service is available on the restricted VIP. Services on the restricted VIP typically either support VPC Service Controls or are core infrastructure services required for the functioning of Google Cloud. Corresponds to the JSON property availableOnRestrictedVip

Returns:

  • (Boolean)


1926
1927
1928
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1926

def available_on_restricted_vip
  @available_on_restricted_vip
end

#known_limitationsBoolean Also known as: known_limitations?

True if the service is supported with some limitations. Check documentation for details. Corresponds to the JSON property knownLimitations

Returns:

  • (Boolean)


1934
1935
1936
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1934

def known_limitations
  @known_limitations
end

#nameString

The service name or address of the supported service, such as service. googleapis.com. Corresponds to the JSON property name

Returns:

  • (String)


1941
1942
1943
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1941

def name
  @name
end

#support_stageString

The support stage of the service. Corresponds to the JSON property supportStage

Returns:

  • (String)


1946
1947
1948
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1946

def support_stage
  @support_stage
end

#supported_methodsArray<Google::Apis::AccesscontextmanagerV1::MethodSelector>

The list of the supported methods. This field exists only in response to GetSupportedService Corresponds to the JSON property supportedMethods



1952
1953
1954
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1952

def supported_methods
  @supported_methods
end

#titleString

The name of the supported product, such as 'Cloud Product API'. Corresponds to the JSON property title

Returns:

  • (String)


1957
1958
1959
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1957

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1964

def update!(**args)
  @available_on_restricted_vip = args[:available_on_restricted_vip] if args.key?(:available_on_restricted_vip)
  @known_limitations = args[:known_limitations] if args.key?(:known_limitations)
  @name = args[:name] if args.key?(:name)
  @support_stage = args[:support_stage] if args.key?(:support_stage)
  @supported_methods = args[:supported_methods] if args.key?(:supported_methods)
  @title = args[:title] if args.key?(:title)
end