Class: Google::Apis::AccesscontextmanagerV1::VpcAccessibleServices
- Inherits:
-
Object
- Object
- Google::Apis::AccesscontextmanagerV1::VpcAccessibleServices
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb
Overview
Specifies how APIs are allowed to communicate within the Service Perimeter.
Instance Attribute Summary collapse
-
#allowed_service_patterns ⇒ Array<Google::Apis::AccesscontextmanagerV1::ServicePattern>
Specifies which Google services are allowed to be accessed from VPC networks in the service perimeter.
-
#allowed_services ⇒ Array<String>
The list of APIs usable within the Service Perimeter.
-
#enable_restriction ⇒ Boolean
(also: #enable_restriction?)
Whether to restrict API calls within the Service Perimeter to the list of APIs specified in 'allowed_services'.
-
#service_patterns_enforcement_scopes ⇒ Array<String>
Defines the enforcement scopes of service patterns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpcAccessibleServices
constructor
A new instance of VpcAccessibleServices.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpcAccessibleServices
Returns a new instance of VpcAccessibleServices.
2504 2505 2506 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_service_patterns ⇒ Array<Google::Apis::AccesscontextmanagerV1::ServicePattern>
Specifies which Google services are allowed to be accessed from VPC networks
in the service perimeter.
Corresponds to the JSON property allowedServicePatterns
2482 2483 2484 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2482 def allowed_service_patterns @allowed_service_patterns end |
#allowed_services ⇒ Array<String>
The list of APIs usable within the Service Perimeter. Must be empty unless '
enable_restriction' is True. You can specify a list of individual services, as
well as include the 'RESTRICTED-SERVICES' value, which automatically includes
all of the services protected by the perimeter.
Corresponds to the JSON property allowedServices
2490 2491 2492 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2490 def allowed_services @allowed_services end |
#enable_restriction ⇒ Boolean Also known as: enable_restriction?
Whether to restrict API calls within the Service Perimeter to the list of APIs
specified in 'allowed_services'.
Corresponds to the JSON property enableRestriction
2496 2497 2498 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2496 def enable_restriction @enable_restriction end |
#service_patterns_enforcement_scopes ⇒ Array<String>
Defines the enforcement scopes of service patterns.
Corresponds to the JSON property servicePatternsEnforcementScopes
2502 2503 2504 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2502 def service_patterns_enforcement_scopes @service_patterns_enforcement_scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2509 2510 2511 2512 2513 2514 |
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 2509 def update!(**args) @allowed_service_patterns = args[:allowed_service_patterns] if args.key?(:allowed_service_patterns) @allowed_services = args[:allowed_services] if args.key?(:allowed_services) @enable_restriction = args[:enable_restriction] if args.key?(:enable_restriction) @service_patterns_enforcement_scopes = args[:service_patterns_enforcement_scopes] if args.key?(:service_patterns_enforcement_scopes) end |