Class: Google::Apis::AccesscontextmanagerV1::VpcAccessibleServices

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/accesscontextmanager_v1/classes.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb,
lib/google/apis/accesscontextmanager_v1/representations.rb

Overview

Specifies how APIs are allowed to communicate within the Service Perimeter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpcAccessibleServices

Returns a new instance of VpcAccessibleServices.



1765
1766
1767
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_servicesArray<String>

The list of APIs usable within the Service Perimeter. Must be empty unless ' enable_restriction' is True. You can specify a list of individual services, as well as include the 'RESTRICTED-SERVICES' value, which automatically includes all of the services protected by the perimeter. Corresponds to the JSON property allowedServices

Returns:

  • (Array<String>)


1756
1757
1758
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1756

def allowed_services
  @allowed_services
end

#enable_restrictionBoolean Also known as: enable_restriction?

Whether to restrict API calls within the Service Perimeter to the list of APIs specified in 'allowed_services'. Corresponds to the JSON property enableRestriction

Returns:

  • (Boolean)


1762
1763
1764
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1762

def enable_restriction
  @enable_restriction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1770
1771
1772
1773
# File 'lib/google/apis/accesscontextmanager_v1/classes.rb', line 1770

def update!(**args)
  @allowed_services = args[:allowed_services] if args.key?(:allowed_services)
  @enable_restriction = args[:enable_restriction] if args.key?(:enable_restriction)
end